/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api

import android.content.Context
import dk.nsp.BuildFlavor
import dk.nsp.api.careplan.ICareplanController
import dk.nsp.api.cms.ICMSController
import dk.nsp.api.configuration.IConfigurationController
import dk.nsp.api.datacard.IDataCardController
import dk.nsp.api.documentation.IDocumentationController
import dk.nsp.api.notes.INotesController
import dk.nsp.api.observations.IObservationsController
import dk.nsp.mingraviditet.api.BuildConfig

interface IBackendApiLayer {
    val configurationController: IConfigurationController
    val careplanController: ICareplanController
    val maternityDataCardController: IDataCardController
    val notesController: INotesController
    val observationsController: IObservationsController
    val cmsController: ICMSController
    val documentationController: IDocumentationController

    companion object {
        private var instance: IBackendApiLayer? = null

        fun getLayer(context: Context): IBackendApiLayer {
            return instance ?: when (BuildFlavor.from(BuildConfig.FLAVOR)) {
                BuildFlavor.Mock -> BackendApiLayerMock().apply {
                    instance = this
                }
                else -> BackendApiLayerImpl(context.applicationContext)
                    .apply {
                        instance = this
                    }
            }
        }
    }
}

fun Context.getBackendApiLayer(): IBackendApiLayer {
    return IBackendApiLayer.getLayer(this.applicationContext)
}
