/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.auth.keyserver

import dk.nsp.api.auth.keyserver.models.KeyModelDTO
import retrofit2.http.GET
import retrofit2.http.Query

interface KeyServerApi {
    /**
     * Gets a [KeyModelDTO] via a given [secret] and [keyId] if they match
     * @param secret String
     * @param keyId String
     * @return [KeyModelDTO]
     */
    @GET("/keyservice/key")
    suspend fun getKey(
        @Query("secret") secret: String,
        @Query("keyid") keyId: String,
    ): KeyModelDTO

    /**
     * Gets a [KeyModelDTO] via the given [keyId] and [longsecret] if they match
     * @param longsecret String
     * @param keyId String
     * @return [KeyModelDTO]
     */
    @GET("/keyservice/longkey")
    suspend fun getKeyViaLongSecret(
        @Query("longsecret") longsecret: String,
        @Query("keyid") keyId: String,
    ): KeyModelDTO

    /**
     * Creates a new key
     * @param secret  String
     * @return [KeyModelDTO]
     */
    @GET("/keyservice/createkey")
    suspend fun createKey(@Query("secret") secret: String): KeyModelDTO
}
