/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.auth.keyserver

import com.squareup.moshi.Moshi
import com.squareup.moshi.kotlin.reflect.KotlinJsonAdapterFactory
import dk.nsp.api.auth.keyserver.models.KeyModelDTO
import dk.nsp.api.util.CustomOkHttpClient
import dk.nsp.mingraviditet.api.BuildConfig
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.tryOrFailed
import retrofit2.Retrofit
import retrofit2.converter.moshi.MoshiConverterFactory

class KeyServerController(private val keyServerApi: KeyServerApi) : IKeyServerController {
    override suspend fun createKey(secret: String): ResultWrapper<KeyModelDTO> {
        return tryOrFailed {
            keyServerApi.createKey(secret)
        }
    }

    override suspend fun getKey(password: String, keyId: String): ResultWrapper<KeyModelDTO> {
        return tryOrFailed {
            keyServerApi.getKey(password, keyId)
        }
    }

    override suspend fun getKeyViaLongSecret(
        longSecret: String,
        keyId: String,
    ): ResultWrapper<KeyModelDTO> {
        return tryOrFailed {
            keyServerApi.getKeyViaLongSecret(longSecret, keyId)
        }
    }

    companion object {
        private var instance: KeyServerController? = null

        private val moshiFactory = MoshiConverterFactory.create(
            Moshi.Builder()
                .addLast(KotlinJsonAdapterFactory())
                .build(),
        )

        fun get(): KeyServerController {
            return instance
                ?: KeyServerController(
                    Retrofit.Builder()
                        .baseUrl(BuildConfig.KeyCloakServer)
                        .addConverterFactory(moshiFactory)
                        .client(CustomOkHttpClient.getClientWithoutAuth())
                        .build()
                        .create(KeyServerApi::class.java),
                ).apply {
                    instance = this
                }
        }
    }
}
