/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.cms

import dk.nsp.api.cms.models.ArticleCategoryDTO
import dk.nsp.api.cms.models.ChecklistDTO
import dk.nsp.api.cms.models.DictionaryEntryDTO
import dk.nsp.api.cms.models.FAQItemDTO
import dk.nsp.api.cms.models.PageDTO
import dk.nsp.api.cms.models.RecommendedArticlesDTO
import dk.nsp.api.util.extensions.asyncIO
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.tryOrFailed
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

class CMSControllerImpl(private val api: CMSApi) : ICMSController {
    override fun getDictionary(scope: CoroutineScope): Deferred<ResultWrapper<List<DictionaryEntryDTO>>> =
        scope.asyncIO {
            tryOrFailed {
                api.getDictionary()
            }
        }

    override fun getFAQ(scope: CoroutineScope): Deferred<ResultWrapper<List<FAQItemDTO>>> =
        scope.asyncIO {
            tryOrFailed {
                api.getFAQ()
            }
        }

    override fun getArticleSections(scope: CoroutineScope): Deferred<ResultWrapper<List<ArticleCategoryDTO>>> =
        scope.asyncIO {
            tryOrFailed {
                api.getArticles()
            }
        }

    override fun getArticleCategories(
        scope: CoroutineScope,
        week: Int,
    ): Deferred<ResultWrapper<RecommendedArticlesDTO>> = scope.asyncIO {
        tryOrFailed {
            api.getArticleCategories(week)
        }
    }

    override fun getAfterBirthArticleCategories(
        scope: CoroutineScope,
        afterBirthWeek: Int,
    ): Deferred<ResultWrapper<RecommendedArticlesDTO>> = scope.asyncIO {
        tryOrFailed {
            api.getAfterBirthArticleCategories(afterBirthWeek)
        }
    }

    override fun searchArticles(
        scope: CoroutineScope,
        query: String,
    ): Deferred<ResultWrapper<List<ArticleCategoryDTO>>> = scope.asyncIO {
        tryOrFailed {
            api.searchArticles(query)
        }
    }

    override fun getChecklists(scope: CoroutineScope): Deferred<ResultWrapper<List<ChecklistDTO>>> =
        scope.asyncIO {
            tryOrFailed {
                api.getChecklists()
            }
        }

    override fun getPageContent(
        scope: CoroutineScope,
        pagePath: String,
    ): Deferred<ResultWrapper<PageDTO>> = scope.asyncIO {
        tryOrFailed {
            api.getPageContentFor(pagePath)
        }
    }
}
