/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.documentation

import dk.nsp.api.util.EpisodeOfCareHeader
import dk.nsp.api.util.extensions.asyncIO
import dk.nsp.shared.ApiCallCallFailed
import dk.nsp.shared.ApiCallCallSuccess
import dk.nsp.shared.Failed
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.Success
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

class DocumentationControllerImpl(private val api: DocumentationAPI) : IDocumentationController {
    override suspend fun getEmployerDocumentation(
        scope: CoroutineScope,
        episodeOfCareId: String,
    ): Deferred<ResultWrapper<Unit>> = scope.asyncIO {
        val result = api.getEmployerDocumentation(
            EpisodeOfCareHeader.createWith(
                episodeOfCareId,
            ),
        )
        when (result) {
            is ApiCallCallSuccess -> return@asyncIO Success(Unit)
            is ApiCallCallFailed -> return@asyncIO Failed(result.error)
        }
    }

    override suspend fun getPersonalDocumentation(
        scope: CoroutineScope,
        episodeOfCareId: String,
    ): Deferred<ResultWrapper<Unit>> = scope.asyncIO {
        val result = api.getPersonalDocumentation(
            EpisodeOfCareHeader.createWith(episodeOfCareId),
        )
        when (result) {
            is ApiCallCallSuccess -> return@asyncIO Success(Unit)
            is ApiCallCallFailed -> return@asyncIO Failed(result.error)
        }
    }
}
