/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.util

import dk.nsp.api.auth.AuthController
import dk.nsp.mingraviditet.api.BuildConfig
import okhttp3.ConnectionSpec
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import java.util.concurrent.TimeUnit

object CustomOkHttpClient {
    private fun createDefaultBuilder(): OkHttpClient.Builder {
        val builder = OkHttpClient.Builder()
            .connectTimeout(1, TimeUnit.MINUTES)
            .writeTimeout(1, TimeUnit.MINUTES)
            .readTimeout(30, TimeUnit.SECONDS)

        // force https
        builder.connectionSpecs(listOf(ConnectionSpec.MODERN_TLS))
        // Check if we should enable logging of all network to console
        if (BuildConfig.AllowLogNetwork) {
            builder.addNetworkInterceptor(
                HttpLoggingInterceptor().apply {
                    level = HttpLoggingInterceptor.Level.BODY
                },
            )
        }

        return builder
    }

    private var secureClientWithAuth: OkHttpClient? = null
    fun getSecureClientWithAuth(authController: AuthController): OkHttpClient {
        return secureClientWithAuth
            ?: createDefaultBuilder()
                .addInterceptor(
                    AuthInterceptor(authController),
                )
                .build()
                .apply {
                    secureClientWithAuth = this
                }
    }

    private var defaultClientWithoutAuth: OkHttpClient? = null
    fun getClientWithoutAuth(): OkHttpClient {
        return createDefaultBuilder()
            .build().apply {
                defaultClientWithoutAuth = this
            }
    }
}
