/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.util

import net.openid.appauth.AuthorizationException
import retrofit2.HttpException

@JvmInline
value class ThrowableNetworkErrorsApi(val throwable: Throwable)

inline val Throwable.networkErrorsApi: ThrowableNetworkErrorsApi
    get() = ThrowableNetworkErrorsApi(this)

fun ThrowableNetworkErrorsApi.isHttpErrorWithCode(code: Int): Boolean {
    val asHttpException = throwable as? HttpException
    return asHttpException?.code() == code
}

fun ThrowableNetworkErrorsApi.isRefreshTokenExpired(): Boolean {
    return throwable is AuthorizationException &&
        throwable.isRefreshTokenExpired()
}

/**
 * Checks if an authorization exception was due to an expired refresh token.
 * @receiver AuthorizationException
 * @return Boolean true if refresh token is expired
 */
fun AuthorizationException.isRefreshTokenExpired(): Boolean =
    errorDescription?.contains("refresh token expired", true) == true ||
        error?.contains("invalid_grant", true) == true
