/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.datacard

import dk.nsp.models.CprIdentifiedPerson
import dk.nsp.models.DataCard
import dk.nsp.models.PersonName
import dk.nsp.shared.ApiCallCallFailed
import dk.nsp.shared.ApiCallCallSuccess
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIsAndApply
import io.mockk.coEvery
import io.mockk.mockk
import kotlinx.coroutines.runBlocking
import org.junit.jupiter.api.Test

class DataCardControllerImplTest {

    class GetMaternityDataCard {
        val failingApi = mockk<DataCardAPI> {
            coEvery {
                getDataCard()
            } returns ApiCallCallFailed(Exception("Could not fetch data card"))
        }

        val api = mockk<DataCardAPI> {
            coEvery { getDataCard() } returns ApiCallCallSuccess(
                listOf(
                    DataCard(
                        "id",
                        CprIdentifiedPerson(PersonName()),
                    ),
                ),
            )
        }

        @Test
        fun success() = runBlocking {
            DataCardControllerImpl(api)
                .getMaternityDataCard(this)
                .await()
                .assertIsAndApply<Success<List<DataCard>>> {
                    value.size.assertEquals(1)
                    value.getOrNull(0).assertEquals(
                        DataCard(
                            "id",
                            CprIdentifiedPerson(PersonName()),
                        ),
                    )
                }
        }

        @Test
        fun failed() = runBlocking {
            DataCardControllerImpl(failingApi)
                .getMaternityDataCard(this)
                .await()
                .assertIsAndApply<Failed> {
                    error.message.assertEquals("Could not fetch data card")
                }
        }
    }
}
