/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.documentation

import dk.nsp.shared.ApiCallCallFailed
import dk.nsp.shared.ApiCallCallSuccess
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIs
import dk.nsp.testassertions.assertIsAndApply
import io.mockk.coEvery
import io.mockk.mockk
import kotlinx.coroutines.runBlocking
import org.junit.jupiter.api.Test

class DocumentationControllerImplTest {

    class GetEmployerDocumentation {
        private val failingApi = mockk<DocumentationAPI> {
            coEvery {
                getEmployerDocumentation(any())
            } returns ApiCallCallFailed(Exception("Could not get docs"))
        }

        private val api = mockk<DocumentationAPI> {
            coEvery {
                getEmployerDocumentation(any())
            } returns ApiCallCallSuccess(Unit)
        }

        @Test
        fun success() = runBlocking {
            DocumentationControllerImpl(api)
                .getEmployerDocumentation(this, "")
                .await()
                .assertIs<Success<Unit>>()
        }

        @Test
        fun failed() = runBlocking {
            DocumentationControllerImpl(failingApi)
                .getEmployerDocumentation(this, "")
                .await()
                .assertIsAndApply<Failed> {
                    error.message.assertEquals("Could not get docs")
                }
        }
    }

    class GetPersonalDocumentation {
        private val failingApi = mockk<DocumentationAPI> {
            coEvery {
                getPersonalDocumentation(any())
            } returns ApiCallCallFailed(Exception("Could not get docs"))
        }

        private val api = mockk<DocumentationAPI> {
            coEvery {
                getPersonalDocumentation(any())
            } returns ApiCallCallSuccess(Unit)
        }

        @Test
        fun success() = runBlocking {
            DocumentationControllerImpl(api)
                .getPersonalDocumentation(this, "")
                .await()
                .assertIs<Success<Unit>>()
        }

        @Test
        fun failed() = runBlocking {
            DocumentationControllerImpl(failingApi)
                .getPersonalDocumentation(this, "")
                .await()
                .assertIsAndApply<Failed> {
                    error.message.assertEquals("Could not get docs")
                }
        }
    }
}
