/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.util.converters

import dk.nsp.testassertions.assertEquals
import org.junit.jupiter.api.Nested
import org.junit.jupiter.api.Test
import java.math.BigDecimal
import java.time.LocalDateTime
import java.time.ZoneId

class MoshiConvertersTest {

    @Nested
    inner class LocalDateTimeConverterTest {
        private val converter = LocalDateTimeConverter()

        @Test
        fun toJson() {
            val localDate = LocalDateTime.of(2020, 3, 12, 12, 0, 3)
            val result = converter.toJson(localDate)

            result.assertEquals("2020-03-12T12:00:03.000Z")
        }

        @Test
        fun fromJson() {
            val source = "2020-03-12T14:00:03.000Z"
            val result = converter.fromJson(source)

            val secondsInAnHour = 60 * 60
            val offsetInHours = ZoneId.systemDefault().rules.getOffset(result).totalSeconds / secondsInAnHour

            result.year.assertEquals(2020)
            result.monthValue.assertEquals(3)
            result.dayOfMonth.assertEquals(12)
            result.hour.assertEquals(14 + offsetInHours)
            result.minute.assertEquals(0)
            result.second.assertEquals(3)
        }
    }

    @Nested
    inner class BigDecimalAdapterTest {
        private val converter = BigDecimalAdapter()

        @Test
        fun toJson() {
            val source = BigDecimal("10.3")
            converter.toJson(source).assertEquals("10.3")
        }

        @Test
        fun fromJson() {
            val source = "10.3"
            converter.fromJson(source).assertEquals(BigDecimal("10.3"))
        }
    }
}
