/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.domain

import android.content.Context
import com.commonsense.android.kotlin.system.extensions.getColorSafe
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.util.extensions.getColorFromAttr
import dk.nsp.util.textmodel.TextModel

sealed class InfoBoxModel(val textModel: TextModel) {
    fun getBackgroundColor(context: Context): Int {
        return when (this) {
            is Orange -> context.getColorSafe(R.color.tree_poppy)
            is Primary -> context.getColorFromAttr(android.R.attr.colorPrimary)
            is Unknown -> context.getColorSafe(android.R.color.transparent)
        }
    }

    class Primary(textModel: TextModel) : InfoBoxModel(textModel)
    class Orange(textModel: TextModel? = null) :
        InfoBoxModel(textModel ?: TextModel.from(R.string.journal_bottom_previous_info_text))

    object Unknown : InfoBoxModel(TextModel.Companion.from(""))
}
