/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2018 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.common

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import dk.nsp.mingraviditet.databinding.EmptyStateFullHeightBinding
import dk.nsp.util.textmodel.TextModel

class EmptyStateFragment : Fragment() {

    private var title: TextModel? = null
    private var description: TextModel? = null

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        val binding = EmptyStateFullHeightBinding.inflate(inflater, container, false)

        if (title == null || description == null) {
            title = savedInstanceState?.getParcelable(titleBundleKey)
            description = savedInstanceState?.getParcelable(descriptionBundleKey)
        }

        binding.titleText = title
        binding.descriptionText = description

        return binding.root
    }

    override fun onSaveInstanceState(outState: Bundle) {
        outState.putParcelable(titleBundleKey, title)
        outState.putParcelable(descriptionBundleKey, description)

        super.onSaveInstanceState(outState)
    }

    companion object {
        const val titleBundleKey = "EmptyStateTitleBundleKey"
        const val descriptionBundleKey = "EmptyStateDescriptionBundleKey"
        fun newInstance(title: TextModel, description: TextModel): EmptyStateFragment =
            EmptyStateFragment().apply {
                this.title = title
                this.description = description
            }
    }
}
