/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.appointments.details

import android.content.res.ColorStateList
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import com.commonsense.android.kotlin.views.extensions.visibleOrGone
import com.google.android.material.tabs.TabLayoutMediator
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentCareplanActivityDetailsBinding
import dk.nsp.mingraviditet.ui.main.appointments.details.viewpager.CareplanActivityDetailsPagerAdapter
import dk.nsp.mingraviditet.ui.main.appointments.extensions.getStatusChipBackgroundColor
import dk.nsp.mingraviditet.ui.main.appointments.extensions.getStatusTextModel
import dk.nsp.mingraviditet.util.extensions.bindingadapters.setTextModel
import dk.nsp.models.Activity

@AndroidEntryPoint
class CareplanActivityDetailsFragment : Fragment() {

    private lateinit var binding: FragmentCareplanActivityDetailsBinding

    private val vm: CareplanActivityDetailsViewModel by viewModels()

    private var viewPagerAdapter: CareplanActivityDetailsPagerAdapter? = null

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        binding = FragmentCareplanActivityDetailsBinding.inflate(inflater, container, false)
        binding.lifecycleOwner = viewLifecycleOwner
        binding.vm = vm

        binding.toolbar.setNavigationOnClickListener { onBackPressed() }

        // Set correct text for info box
        vm.activityOverdueAndNotFinishedWarningInfo.observe(viewLifecycleOwner) {
            binding.overdueDateWarning.root.visibleOrGone(it != null)
            if (it != null) {
                binding.overdueDateWarning.setBottomInfo(it)
            }
        }

        vm.careplanActivity.observe(viewLifecycleOwner) {
            binding.activityStatusBadge.backgroundTintList =
                ColorStateList.valueOf(it.getStatusChipBackgroundColor(binding.root.context))
            binding.activityStatusBadge.setTextModel(it.getStatusTextModel())
            setupViewPager(it)
        }

        return binding.root
    }

    private fun setupViewPager(activityData: Activity) {
        this.activity?.let {
            viewPagerAdapter = CareplanActivityDetailsPagerAdapter(it, activityData)
        }

        binding.viewPager.adapter = viewPagerAdapter
        TabLayoutMediator(binding.tabLayout, binding.viewPager) { tab, position ->
            when (position) {
                0 -> tab.setText(R.string.appointment_details_description)
                1 -> tab.setText(R.string.appointment_details_measurements)
                2 -> tab.setText(R.string.appointment_details_journalnotes)
            }
        }.attach()
    }

    companion object {
        const val CareplanActivityDetailsDataKey = "data"
    }
}
