/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.appointments.details

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.map
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.domain.repository.CareplanRepository
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.domain.InfoBoxModel
import dk.nsp.mingraviditet.ui.main.appointments.extensions.isOverdueAndNotFinished
import dk.nsp.mingraviditet.util.extensions.getValue
import dk.nsp.models.Activity
import dk.nsp.util.textmodel.TextModel
import javax.inject.Inject

@HiltViewModel
class CareplanActivityDetailsViewModel @Inject constructor(
    private val careplanRepository: CareplanRepository,
    private val savedStateHandle: SavedStateHandle,
) : ViewModel() {

    private val _careplanActivity = MutableLiveData<Activity>()
    val careplanActivity by _careplanActivity

    val activityOverdueAndNotFinishedWarningInfo: LiveData<InfoBoxModel?> =
        _careplanActivity.map {
            if (it.isOverdueAndNotFinished()) {
                InfoBoxModel.Primary(TextModel.from(R.string.appointment_overdue_info))
            } else {
                null
            }
        }

    init {
        savedStateHandle.get<ActivityNavData>(CareplanActivityDetailsFragment.CareplanActivityDetailsDataKey)
            ?.let { navData ->
                when (navData) {
                    is ActivityNavData.WithActivity -> navData.activity
                    is ActivityNavData.WithId -> careplanRepository.getCareplanActivity(navData.activityId)
                }?.let {
                    _careplanActivity.postValue(it)
                }
            }
    }
}
