/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.appointments.details.viewpager

import android.os.Bundle
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentActivity
import androidx.viewpager2.adapter.FragmentStateAdapter
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.ui.common.EmptyStateFragment
import dk.nsp.mingraviditet.ui.main.appointments.details.viewpager.description.CareplanActivityDescriptionPageFragment
import dk.nsp.mingraviditet.ui.main.appointments.details.viewpager.journalnotes.CareplanActivityJournalNotesPageFragment
import dk.nsp.mingraviditet.ui.main.appointments.details.viewpager.observations.CareplanActivityObservationsPageFragment
import dk.nsp.models.Activity
import dk.nsp.util.textmodel.TextModel

class CareplanActivityDetailsPagerAdapter(
    fa: FragmentActivity,
    careplanActivity: Activity,
) : FragmentStateAdapter(fa) {
    override fun getItemCount(): Int = 3

    private val descriptionFragment = if (careplanActivity.description != null) {
        CareplanActivityDescriptionPageFragment().apply {
            val bundle = Bundle().apply {
                putParcelable(
                    CareplanActivityDescriptionPageFragment.careplanActivityBundleKey,
                    careplanActivity,
                )
            }
            arguments = bundle
        }
    } else {
        EmptyStateFragment.newInstance(
            TextModel.from(R.string.appointment_details_description_empty_title),
            TextModel.from(R.string.appointment_details_description_empty_description),
        )
    }

    private val observationFragment = if (careplanActivity.observations?.isNotEmpty() == true) {
        CareplanActivityObservationsPageFragment().apply {
            val bundle = Bundle().apply {
                putParcelable(
                    CareplanActivityObservationsPageFragment.careplanActivityBundleKey,
                    careplanActivity,
                )
            }
            arguments = bundle
        }
    } else {
        EmptyStateFragment.newInstance(
            TextModel.from(R.string.appointment_details_measurement_empty_title),
            TextModel.from(R.string.appointment_details_measurement_empty_description),
        )
    }

    private val journalNoteFragment = if (careplanActivity.note != null) {
        CareplanActivityJournalNotesPageFragment().apply {
            val bundle = Bundle().apply {
                putParcelable(
                    CareplanActivityJournalNotesPageFragment.careplanActivityBundleKey,
                    careplanActivity,
                )
            }
            arguments = bundle
        }
    } else {
        EmptyStateFragment.newInstance(
            TextModel.from(R.string.appointment_details_journalnotes_empty_title),
            TextModel.from(R.string.appointment_details_journalnotes_empty_description),
        )
    }

    override fun createFragment(position: Int): Fragment {
        return when (position) {
            0 -> descriptionFragment
            1 -> observationFragment
            2 -> journalNoteFragment
            else -> throw NotImplementedError("Der findes ingen fragmenter for denne position")
        }
    }
}
