/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.appointments.extensions

import android.content.Context
import androidx.annotation.ColorInt
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.util.extensions.getColorFromAttr
import dk.nsp.mingraviditet.util.extensions.getDotColorBySeed
import dk.nsp.mingraviditet.util.extensions.toTextModelOrDefault
import dk.nsp.models.Activity
import dk.nsp.shared.util.extensions.isAfterNow
import dk.nsp.shared.util.extensions.toDefaultMonthDisplay
import dk.nsp.util.textmodel.TextModel

fun Activity?.hasObservationsOrNotes(): Boolean {
    return this?.note != null || this?.observations?.isNotEmpty() == true
}

fun Activity.isPlannedOrExpected(): Boolean {
    return status == Activity.Status.Expected || status == Activity.Status.Planned
}

fun Activity.isFinished(): Boolean = status == Activity.Status.Finished

fun Activity?.getSubtitleText(): TextModel {
    return this?.let {
        when {
            scheduledString != null && this.isPlannedOrExpected() -> scheduledString
            conductedTime != null -> conductedTime?.toDefaultMonthDisplay()
            plannedTime?.from != null -> plannedTime?.from?.toDefaultMonthDisplay()
            else -> scheduledString
        }
    }.toTextModelOrDefault()
}

fun Activity?.getStatusChipBackgroundColor(context: Context): Int {
    return if (this?.isFinished() == true) {
        context.getColorFromAttr(R.attr.activityStatusFinishedBackgroundColor)
    } else {
        context.getColorFromAttr(R.attr.activityStatusPlannedBackgroundColor)
    }
}

fun Activity.getStatusTextModel(): TextModel {
    return if (isFinished()) {
        TextModel.from(R.string.appointment_details_finished_badge)
    } else {
        TextModel.from(R.string.appointment_details_planned_badge)
    }
}

@ColorInt
fun Activity.getDotIndicatorColorBySeed(context: Context): Int {
    val seed = careplanId

    return getDotColorBySeed(context, seed)
}

fun Activity.isSortDateInFuture(): Boolean {
    return sortDate?.isAfterNow() == true
}

fun Activity?.isOverdueAndNotFinished(): Boolean {
    return this?.isSortDateInFuture() == false && this.isPlannedOrExpected()
}
