/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.appointments.rows

import android.content.res.ColorStateList
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.ActivityRowBinding
import dk.nsp.mingraviditet.ui.main.appointments.extensions.isFinished
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.getColorFromAttr
import dk.nsp.models.Activity

data class ActivityRowBindingModel(val activity: Activity, val onClick: () -> Unit)

class ActivityRow(val model: ActivityRowBindingModel) :
    RecyclerAdapterView<ActivityRowBinding> {

    override fun bindData(viewHolder: BindingViewHolder<ActivityRowBinding>) {
        val ctx = viewHolder.binding.root.context
        viewHolder.binding.bindingModel = model

        if (model.activity.isFinished()) {
            val pastBackgroundColor = ctx.getColorFromAttr(R.attr.pastTimelineBackgroundColor)
            viewHolder.binding.root.setBackgroundColor(pastBackgroundColor)
            viewHolder.binding.verticalTimeline.backgroundTintList =
                ColorStateList.valueOf(ctx.getColorFromAttr(R.attr.pastTimelineColor))
        } else {
            val backgroundColor = ctx.getColorFromAttr(com.google.android.material.R.attr.backgroundColor)
            viewHolder.binding.root.setBackgroundColor(backgroundColor)

            viewHolder.binding.verticalTimeline.backgroundTintList =
                ColorStateList.valueOf(ctx.getColorFromAttr(R.attr.futureTimelineColor))
        }
    }

    override val createHolderFunction: DelegationListAdapterInflater<ActivityRowBinding> =
        ActivityRowBinding::inflate
}
