/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.map
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.domain.repository.DataCardRepository
import dk.nsp.mingraviditet.ui.adapterviews.IdentityIllustrationRow
import dk.nsp.mingraviditet.ui.adapterviews.models.SectionType
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.livedata.SingleEvent
import javax.inject.Inject

@HiltViewModel
class JournalViewModel @Inject constructor(
    dataCardRepository: DataCardRepository,
    private val savedStateHandle: SavedStateHandle,
) : ViewModel() {

    val sectionCards: LiveData<List<RecyclerAdapterView<*>>> =
        dataCardRepository.currentDataCard.map {
            createSectionCards()
        }

    private val _onNavigateToSection: MutableLiveData<SingleEvent<JournalSection>> =
        MutableLiveData()
    val onNavigateToSection: LiveData<SingleEvent<JournalSection>> = _onNavigateToSection

    private fun createSectionCards(): List<RecyclerAdapterView<*>> =
        listOf(
            // Målinger
            JournalSection.Measurements.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.Measurements))
            },

            // Scanninger
            JournalSection.Scans.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.Scans))
            },

            // Undersøgelsesresultater
            JournalSection.Screenings.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.Screenings))
            },

            // Journalnoter
            JournalSection.JournalNotes.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.JournalNotes))
            },

            // Rundt om graviditeten
            JournalSection.AroundThePregnancy.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.AroundThePregnancy))
            },

            // Samlet vurdering and tildelt forløb
            JournalSection.OverallAssessment.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.OverallAssessment))
            },

            // Mine sundhedsfaglige
            JournalSection.HealthCare.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.HealthCare))
            },

            // Personlige oplysninger
            JournalSection.PersonalData.createJournalSectionCardBindingModel {
                _onNavigateToSection.postValue(SingleEvent(JournalSection.PersonalData))
            },
        ).map { JournalSectionCard(it) } + IdentityIllustrationRow(SectionType.Journal)
}
