/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.extensions

import dk.nsp.mingraviditet.R
import dk.nsp.models.PersonalDataSectionNextOfKin
import dk.nsp.util.textmodel.TextModel

fun PersonalDataSectionNextOfKin.Relation?.toTextModel(): TextModel {
    val stringRes = when (this) {
        PersonalDataSectionNextOfKin.Relation.UspecPRRende -> R.string.journal_section_personal_data_next_of_kin_relation_unspecified_relative
        PersonalDataSectionNextOfKin.Relation.IngenRelationer -> R.string.journal_section_personal_data_next_of_kin_relation_no_relations
        PersonalDataSectionNextOfKin.Relation.Barn -> R.string.journal_section_personal_data_next_of_kin_relation_child
        PersonalDataSectionNextOfKin.Relation.Mor -> R.string.journal_section_personal_data_next_of_kin_relation_mother
        PersonalDataSectionNextOfKin.Relation.Far -> R.string.journal_section_personal_data_next_of_kin_relation_father
        PersonalDataSectionNextOfKin.Relation.ForLder -> R.string.journal_section_personal_data_next_of_kin_relation_parent
        PersonalDataSectionNextOfKin.Relation.SSkende -> R.string.journal_section_personal_data_next_of_kin_relation_sibling
        PersonalDataSectionNextOfKin.Relation.GtefLle -> R.string.journal_section_personal_data_next_of_kin_relation_spouse
        PersonalDataSectionNextOfKin.Relation.Barnebarn -> R.string.journal_section_personal_data_next_of_kin_relation_grand_child
        PersonalDataSectionNextOfKin.Relation.Svigerbarn -> R.string.journal_section_personal_data_next_of_kin_relation_child_in_law
        PersonalDataSectionNextOfKin.Relation.VrigFamilie -> R.string.journal_section_personal_data_next_of_kin_relation_other_family
        PersonalDataSectionNextOfKin.Relation.Nabo -> R.string.journal_section_personal_data_next_of_kin_relation_neighbor
        PersonalDataSectionNextOfKin.Relation.Samboende -> R.string.journal_section_personal_data_next_of_kin_relation_live_together
        PersonalDataSectionNextOfKin.Relation.RegistreretPartner -> R.string.journal_section_personal_data_next_of_kin_relation_registered_partner
        PersonalDataSectionNextOfKin.Relation.Anden -> R.string.journal_section_personal_data_next_of_kin_relation_other
        PersonalDataSectionNextOfKin.Relation.SN -> R.string.journal_section_personal_data_next_of_kin_relation_son
        PersonalDataSectionNextOfKin.Relation.Datter -> R.string.journal_section_personal_data_next_of_kin_relation_daughter
        else -> R.string.common_missing_data
    }
    return TextModel.from(stringRes)
}
