/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections

import dk.nsp.mingraviditet.databinding.SectionCardListItemBinding
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.util.textmodel.TextModel

data class SectionCardListItemBindingModel(
    val text: TextModel,
    val isLastItem: Boolean = false,
    val notificationCount: Int = 0,
    val onClick: () -> Unit,
)

class JournalSectionCardItem(val model: SectionCardListItemBindingModel) :
    RecyclerAdapterView<SectionCardListItemBinding> {
    private var internalText: String? = null

    override fun bindData(viewHolder: BindingViewHolder<SectionCardListItemBinding>) {
        viewHolder.binding.bm = model

        internalText = model.text.getString(viewHolder.binding.root.resources)
    }

    override val createHolderFunction: DelegationListAdapterInflater<SectionCardListItemBinding> =
        SectionCardListItemBinding::inflate

    override fun isContentTheSameAsInternal(other: RecyclerAdapterView<*>): Boolean {
        val otherCard = other as JournalSectionCardItem

        return this.internalText == otherCard.internalText &&
            model.notificationCount == otherCard.model.notificationCount &&
            model.isLastItem == otherCard.model.isLastItem
    }
}
