/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.measurements.bll

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.chart.models.LineChartConfig
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.chart.models.LineChartSetupData
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.chart.models.LineChartValue
import dk.nsp.models.ObservationTable
import dk.nsp.util.textmodel.TextModel
import dk.nsp.util.toTextModel

fun ObservationTable.toPubismeasurementLineChartData(): LineChartSetupData {
    var yUnit: String? = null

    val chartData = mother?.rows?.mapNotNull { row ->

        if (yUnit == null) {
            yUnit = row.pubismeasurement?.unit
        }

        val week = row.weeksIntoPregnancy?.toFloat()
        val measurement = row.pubismeasurement?.value?.toFloat()

        if (week != null && measurement != null) {
            LineChartValue(
                week,
                measurement,
            )
        } else {
            null
        }
    } ?: emptyList()

    val chartConfig = LineChartConfig(
        TextModel.from(R.string.common_unit_weeks),
        (yUnit ?: "").toTextModel(),
    )

    return LineChartSetupData(
        chartData,
        chartConfig,
    )
}
