/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.measurements.chart.renderers

import android.graphics.Canvas
import android.graphics.Paint
import com.github.mikephil.charting.components.XAxis
import com.github.mikephil.charting.renderer.XAxisRenderer
import com.github.mikephil.charting.utils.MPPointF
import com.github.mikephil.charting.utils.Transformer
import com.github.mikephil.charting.utils.Utils
import com.github.mikephil.charting.utils.ViewPortHandler

class MeasurementsLineChartXAxisRenderer(
    viewPortHandler: ViewPortHandler?,
    xAxis: XAxis?,
    transformer: Transformer?,
) : XAxisRenderer(viewPortHandler, xAxis, transformer) {

    override fun drawLabel(
        canvas: Canvas?,
        formattedLabel: String?,
        x: Float,
        y: Float,
        anchor: MPPointF?,
        angleDegrees: Float,
    ) {
        if (canvas == null || formattedLabel == null) {
            return
        }
        val labelSegments = formattedLabel.split('\n')

        labelSegments.forEachIndexed { index, segment ->
            Utils.drawXAxisValue(
                canvas,
                segment,
                x,
                y + (mAxisLabelPaint.textSize * index),
                mAxisLabelPaint,
                anchor,
                angleDegrees,
            )
        }

        val paint = Paint().apply {
            strokeWidth = 2f
            color = mXAxis.axisLineColor
        }

        canvas.drawLine(x, y, x, y - mXAxis.yOffset, paint)
    }
}
