/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.measurement

import dk.nsp.mingraviditet.ui.main.journal.extensions.toTextModel
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.JournalTableCellData
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.JournalTableClinicalFetusMeasurementType
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.NavigateToActivityCallback
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.NavigateToInfoCallback
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationTableDataType
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationTableRowGenerator
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationsTableActivity
import dk.nsp.mingraviditet.util.extensions.toTextModelOrDefault
import dk.nsp.models.ObservationTableRows
import java.time.LocalDateTime

class ObservationMeasurementTableFetusActivity(
    private val fetusDataValues: ObservationTableRows,
) : ObservationTableRowGenerator {
    override val activityId: String? = fetusDataValues.activityId
    override val date: LocalDateTime? = fetusDataValues.date

    override fun dataTableCellForType(
        measurementType: ObservationTableDataType,
        activityId: String?,
        navigateToActivity: NavigateToActivityCallback,
        navigateToInfo: NavigateToInfoCallback,
    ): JournalTableCellData {
        return when (measurementType) {
            JournalTableClinicalFetusMeasurementType.FetusPresentation -> JournalTableCellData.textWithOptionalValue(
                fetusDataValues.fetusPresentation.toTextModelOrDefault(),
            )
            JournalTableClinicalFetusMeasurementType.FetusWeightEstimate -> JournalTableCellData.textWithOptionalValue(
                fetusDataValues.fetusWeightEstimate.toTextModel(),
            )
            JournalTableClinicalFetusMeasurementType.GestationAge -> JournalTableCellData.textWithOptionalValue(
                fetusDataValues.gestationAge.toTextModelOrDefault(),
            )
            JournalTableClinicalFetusMeasurementType.FetusActivity -> JournalTableCellData.textWithOptionalValue(
                fetusDataValues.fetusActivity?.joinToString("\n") { it }.toTextModelOrDefault(),
            )
            else -> JournalTableCellData.empty()
        }
    }

    companion object {
        fun emptyInstance(activity: ObservationsTableActivity): ObservationMeasurementTableFetusActivity =
            ObservationMeasurementTableFetusActivity(
                ObservationTableRows(
                    activityId = activity.activityId,
                    date = activity.date,
                ),
            )
    }
}
