/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.measurement

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.ui.main.journal.extensions.toTextModel
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.DataTableCellType
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.JournalTableCellData
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.JournalTableClinicalMotherMeasurementType
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.NavigateToActivityCallback
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.NavigateToInfoCallback
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationTableDataType
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationTableRowGenerator
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationsTableActivity
import dk.nsp.mingraviditet.util.extensions.toTextModelOrDefault
import dk.nsp.models.ObservationTableMotherRows
import dk.nsp.util.textmodel.TextModel
import java.time.LocalDateTime

class ObservationMeasurementTableMotherActivity(
    private val motherDataValues: ObservationTableMotherRows?,
) : ObservationTableRowGenerator {
    override val activityId: String? = motherDataValues?.activityId
    override val date: LocalDateTime? = motherDataValues?.date

    override fun dataTableCellForType(
        measurementType: ObservationTableDataType,
        activityId: String?,
        navigateToActivity: NavigateToActivityCallback,
        navigateToInfo: NavigateToInfoCallback,
    ): JournalTableCellData {
        if (motherDataValues == null || measurementType !is JournalTableClinicalMotherMeasurementType) {
            return JournalTableCellData.empty()
        }

        return when (measurementType) {
            JournalTableClinicalMotherMeasurementType.Weight -> JournalTableCellData.textWithOptionalValue(
                motherDataValues.weight.toTextModel(),
            )
            JournalTableClinicalMotherMeasurementType.BloodPressure -> JournalTableCellData.textWithOptionalValue(
                motherDataValues.bloodPressure.toTextModelOrDefault(),
            )
            JournalTableClinicalMotherMeasurementType.Urine -> JournalTableCellData.textWithOptionalValue(
                motherDataValues.urine.toTextModelOrDefault(),
            )
            JournalTableClinicalMotherMeasurementType.Edema -> JournalTableCellData.textWithOptionalValue(
                motherDataValues.edema.toTextModelOrDefault(),
            )
            JournalTableClinicalMotherMeasurementType.PubisMeasurement -> JournalTableCellData.textWithOptionalValue(
                motherDataValues.pubismeasurement.toTextModel(),
            )
            JournalTableClinicalMotherMeasurementType.Activity -> JournalTableCellData(
                TextModel.from(R.string.common_show),
                DataTableCellType.PrimaryButton {
                    navigateToActivity(activityId)
                },
            )
        }
    }

    companion object {
        fun emptyInstance(activity: ObservationsTableActivity) =
            ObservationMeasurementTableMotherActivity(
                ObservationTableMotherRows(
                    activityId = activity.activityId,
                    date = activity.date,
                ),
            )
    }
}
