/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.scan

import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.JournalTableScanFetusMeasurementType
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationTableDataType
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationTableMeasurementRowsSource
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationTableRowGenerator
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationsTableActivity
import dk.nsp.mingraviditet.ui.main.journal.sections.measurements.table.models.common.ObservationsTableDataSource
import dk.nsp.mingraviditet.util.extensions.toTextModelOrDefault
import dk.nsp.models.ScanningObservationTableFetuses
import dk.nsp.util.textmodel.TextModel

class ObservationScanTableFetus(fetusData: ScanningObservationTableFetuses) :
    ObservationsTableDataSource, ObservationTableMeasurementRowsSource {
    private val fetusActivities = fetusData.rows?.map {
        ObservationScanTableFetusActivity(it)
    } ?: emptyList()

    //region ObservationsTableDataSource
    override val id: String? = fetusData.id
    override val title: TextModel = fetusData.name.toTextModelOrDefault()
    override val activityDataTypes: List<ObservationTableDataType> =
        JournalTableScanFetusMeasurementType.orderedDataTypes
    override val activities: List<ObservationsTableActivity> = fetusActivities
    //endregion

    //region ObservationTableMeasurementRowsSource
    override val rows: List<ObservationTableRowGenerator> = fetusActivities
    //endregion
}
