/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.scans

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.JournalDirections
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentJournalScansDetailsBinding
import dk.nsp.mingraviditet.ui.main.journal.JournalSection
import dk.nsp.mingraviditet.ui.widgets.HeaderViewWithIconBindingModel
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.navigateSafe
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled
import dk.nsp.mingraviditet.util.extensions.toDialogData

@AndroidEntryPoint
class JournalScansFragment : Fragment() {

    private val viewModel: JournalScansViewModel by viewModels()

    private val adapter by lazy {
        DelegatingListAdapter(viewLifecycleOwner)
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        val binding = FragmentJournalScansDetailsBinding.inflate(inflater, container, false)
        binding.lifecycleOwner = viewLifecycleOwner
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }
        binding.toolbar.setTitle(R.string.journal_section_scans_title)

        binding.recyclerView.adapter = adapter

        binding.headerModel = HeaderViewWithIconBindingModel(
            JournalSection.Scans.getTitle(),
            JournalSection.Scans.getDescription(),
            JournalSection.Scans.getIcon(),
        )

        viewModel.tableData.observe(viewLifecycleOwner) { tableData ->
            binding.dataTable.updateWithData(tableData)
        }

        viewModel.isRefreshing.observe(viewLifecycleOwner) {
            binding.swipeRefresh.isRefreshing = it
        }

        binding.swipeRefresh.setOnRefreshListener {
            viewModel.onRefreshData()
        }

        viewModel.onDictionary.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(
                JournalScansFragmentDirections.actionJournalScansFragmentToGenericDialogBottomSheet(
                    it.toDialogData(),
                ),
            )
        }

        viewModel.showActivityDetails.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(
                JournalDirections.navJournalGlobalToCareplanActivityDetailsFragment(
                    it,
                ),
            )
        }

        viewModel.showInfo.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(
                JournalScansFragmentDirections.actionJournalScansFragmentToGenericDialogBottomSheet(
                    it,
                ),
            )
        }

        viewModel.rowsToShow.observe(viewLifecycleOwner) {
            adapter.submitList(it)
        }

        return binding.root
    }
}
