/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.sectiondetails

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import androidx.navigation.fragment.navArgs
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.databinding.FragmentJournalKeyValueSectionDetailsBinding
import dk.nsp.mingraviditet.ui.widgets.BottomInfoToggler
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.navigateSafe
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled
import dk.nsp.mingraviditet.util.extensions.toDialogData

@AndroidEntryPoint
class JournalKeyValueSectionDetailsFragment : Fragment() {

    private val args by navArgs<JournalKeyValueSectionDetailsFragmentArgs>()

    val adapter by lazy {
        DelegatingListAdapter(viewLifecycleOwner)
    }

    val viewModel: JournalKeyValueSectionDetailsViewModel by viewModels()

    private var infoToggler: BottomInfoToggler? = null

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        val binding =
            FragmentJournalKeyValueSectionDetailsBinding.inflate(inflater, container, false)
        binding.lifecycleOwner = viewLifecycleOwner
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }
        binding.toolbar.setTitle(args.journalSectionDetailType.getTitle())

        binding.infoTextModel = args.infoTextModel
        infoToggler = BottomInfoToggler(binding.bottomInfo, binding.recyclerView)

        binding.recyclerView.adapter = adapter

        viewModel.rows.observe(viewLifecycleOwner) {
            adapter.submitList(it)
        }

        viewModel.onDictionary.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(
                JournalKeyValueSectionDetailsFragmentDirections.actionJournalSectionDetailsFragmentToGenericDialogBottomSheet(
                    it.toDialogData(),
                ),
            )
        }

        viewModel.isRefreshing.observe(viewLifecycleOwner) {
            binding.swipeRefresh.isRefreshing = it
        }

        binding.swipeRefresh.setOnRefreshListener {
            viewModel.onRefreshData()
        }

        return binding.root
    }
}
