/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.knowledge.article

import android.view.View
import dk.nsp.mingraviditet.databinding.ArticleExcerptTextRowBinding
import dk.nsp.mingraviditet.extensions.disable
import dk.nsp.mingraviditet.util.android.WebViewHelper
import dk.nsp.mingraviditet.util.android.WebViewHelper.setUpDarkModeSupport
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView

class ArticleExcerptRow(private val description: String, private val content: String?) :
    RecyclerAdapterView<ArticleExcerptTextRowBinding> {
    override fun bindData(viewHolder: BindingViewHolder<ArticleExcerptTextRowBinding>) {
        with(viewHolder.binding) {
            webview.visibility = if (content != null) View.VISIBLE else View.GONE
            excerptText.visibility = if (content != null) View.GONE else View.VISIBLE

            excerptText.text = description

            content?.let {
                webview.apply {
                    setUpDarkModeSupport()
                    // Enable js to be able to show videoes
                    settings.javaScriptEnabled = true
                    settings.useWideViewPort = false
                    settings.loadWithOverviewMode = false

                    // Disable scroll on touch
                    disable()

                    val htmlToLoad = WebViewHelper.createHtmlWithStyleSheet(
                        it,
                        root.context,
                    )

                    loadDataWithBaseURL(
                        "file:///android_asset/",
                        htmlToLoad,
                        "text/html",
                        "UTF-8",
                        "",
                    )
                }
            }
        }
    }

    override val createHolderFunction: DelegationListAdapterInflater<ArticleExcerptTextRowBinding> =
        ArticleExcerptTextRowBinding::inflate
}
