/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.knowledge.articles

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import androidx.navigation.fragment.navArgs
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.databinding.FragmentKnowledgeArticlesBinding
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.navigateSafe
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled

@AndroidEntryPoint
class KnowledgeArticlesFragment : Fragment() {

    private val adapter by lazy {
        DelegatingListAdapter(viewLifecycleOwner)
    }

    private val args: KnowledgeArticlesFragmentArgs by navArgs()

    private val articlesViewModel: KnowledgeArticlesViewModel by viewModels()

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        val binding = FragmentKnowledgeArticlesBinding.inflate(inflater, null, false)
        binding.lifecycleOwner = viewLifecycleOwner
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }

        binding.recyclerView.adapter = adapter

        binding.toolbar.title = args.category.name

        articlesViewModel.onData.observe(viewLifecycleOwner) {
            adapter.submitList(it) {
                binding.recyclerView.scheduleLayoutAnimation()
            }
        }

        articlesViewModel.onArticleClicked.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(
                KnowledgeArticlesFragmentDirections.actionKnowledgeArticlesFragmentToKnowledgeArticleFragment(
                    it,
                ),
            )
        }

        return binding.root
    }
}
