/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.knowledge.articles

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.domain.articles.Article
import dk.nsp.domain.articles.ArticleCategory
import dk.nsp.mingraviditet.ui.adapterviews.DetailsHeaderRow
import dk.nsp.mingraviditet.ui.main.knowledge.viewbinding.ArticleCardBindingModel
import dk.nsp.mingraviditet.ui.widgets.HeaderViewWithIconBindingModel
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.toSingleEvent
import dk.nsp.mingraviditet.util.livedata.SingleEvent
import dk.nsp.util.textmodel.TextModel
import javax.inject.Inject

@HiltViewModel
class KnowledgeArticlesViewModel @Inject constructor(
    private val savedStateHandle: SavedStateHandle,
) : ViewModel() {

    private val articles = savedStateHandle.get<ArticleCategory>("category")

    private val _onData: MutableLiveData<List<RecyclerAdapterView<*>>> = MutableLiveData()
    val onData: LiveData<List<RecyclerAdapterView<*>>> = _onData

    private val _onArticleClicked: MutableLiveData<SingleEvent<Article>> = MutableLiveData()
    val onArticleClicked: LiveData<SingleEvent<Article>> = _onArticleClicked

    init {
        articles?.let { getArticlesForCategory(it) }
    }

    private fun getArticlesForCategory(articleCategory: ArticleCategory) {
        val articles = articleCategory.articles
        val rowsToShow = mutableListOf<RecyclerAdapterView<*>>()
        rowsToShow.add(
            DetailsHeaderRow(
                HeaderViewWithIconBindingModel(
                    TextModel.Companion.from(
                        articleCategory.name,
                    ),
                    TextModel.Companion.from(articleCategory.description),
                    null,
                    articleCategory.icon,
                ),
            ),
        )

        val articlesRows = articles.map { article ->
            ArticleCard(
                ArticleCardBindingModel(article) {
                    _onArticleClicked.postValue(article.toSingleEvent())
                },
            )
        }
        rowsToShow.addAll(articlesRows)

        _onData.postValue(rowsToShow)
    }
}
