/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.navigation.NavDirections
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.mingraviditet.ui.adapterviews.IdentityIllustrationRow
import dk.nsp.mingraviditet.ui.adapterviews.models.SectionType
import dk.nsp.mingraviditet.ui.main.more.viewbinding.MoreCardBindingModel
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.extensions.toSingleEvent
import dk.nsp.mingraviditet.util.livedata.SingleEvent
import javax.inject.Inject

@HiltViewModel
class MoreFragmentViewModel @Inject constructor() : ViewModel() {

    private val _rowsToShow = MutableLiveData(createMoreCards())
    val rowsToShow: LiveData<List<RecyclerAdapterView<*>>> = _rowsToShow

    private val _onNavigateToSection: MutableLiveData<SingleEvent<NavDirections>> =
        MutableLiveData()
    val onNavigateToSection: LiveData<SingleEvent<NavDirections>> = _onNavigateToSection

    private fun createMoreCards(): List<RecyclerAdapterView<*>> =
        listOf(
            createMoreCard(MoreSection.Documentation) {
                _onNavigateToSection.postValue(
                    MoreFragmentDirections.actionMoreFragmentToDocumentationFragment()
                        .toSingleEvent(),
                )
            },
            createMoreCard(MoreSection.Support) {
                _onNavigateToSection.postValue(
                    MoreFragmentDirections.actionMoreFragmentToSupportOverviewFragment()
                        .toSingleEvent(),
                )
            },
            createMoreCard(MoreSection.Settings) {
                _onNavigateToSection.postValue(
                    MoreFragmentDirections.actionMoreFragmentToSettingsFragment().toSingleEvent(),
                )
            },
        ) + IdentityIllustrationRow(SectionType.More)

    private fun createMoreCard(
        section: MoreSection,
        unreadSupportMessages: Int = 0,
        onClick: () -> Unit,
    ): MoreCard {
        return MoreCard(
            MoreCardBindingModel(
                section.getTitle(),
                section.getDescription(),
                section.getIcon(),
                unreadSupportMessages,
                onClick,
            ),
        )
    }
}
