/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more

import android.os.Parcelable
import androidx.annotation.DrawableRes
import dk.nsp.mingraviditet.R
import dk.nsp.util.textmodel.TextModel
import kotlinx.parcelize.Parcelize

@Parcelize
enum class MoreSection : Parcelable {
    Documentation, Support, Settings;

    fun getTitle(): TextModel = TextModel.from(
        when (this) {
            Documentation -> R.string.more_documentation_title
            Support -> R.string.more_support_title
            Settings -> R.string.more_settings_title
        },
    )

    fun getDescription(): TextModel = TextModel.from(
        when (this) {
            Documentation -> R.string.more_documentation_description
            Support -> R.string.more_support_description
            Settings -> R.string.more_settings_description
        },
    )

    @DrawableRes
    fun getIcon(): Int = when (this) {
        Documentation -> R.drawable.ic_documentation
        Support -> R.drawable.ic_support
        Settings -> R.drawable.ic_settings
    }
}
