/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.documentation

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.DocumentationCardWithButtonRowBinding
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.util.textmodel.TextModel
import dk.nsp.util.textmodel.TextResourceModel

data class DocumentationCardData(
    val title: TextModel,
    val body: TextModel,
    val buttonText: TextModel? = null,
    val isLoading: Boolean = false,
    val isButtonEnabled: Boolean = false,
    val onClick: (() -> Unit)? = null,
)

class DocumentationCardWithButtonRow(val data: DocumentationCardData) :
    RecyclerAdapterView<DocumentationCardWithButtonRowBinding> {

    override fun bindData(viewHolder: BindingViewHolder<DocumentationCardWithButtonRowBinding>) {
        viewHolder.binding.bm = data
    }

    override val createHolderFunction: DelegationListAdapterInflater<DocumentationCardWithButtonRowBinding> =
        DocumentationCardWithButtonRowBinding::inflate

    override fun isContentTheSameAsInternal(other: RecyclerAdapterView<*>): Boolean {
        val otherCard = other as? DocumentationCardWithButtonRow ?: return false
        return otherCard.data.body == data.body &&
            otherCard.data.buttonText == data.buttonText &&
            otherCard.data.isLoading == data.isLoading &&
            otherCard.data.isButtonEnabled == data.isButtonEnabled
    }

    override fun isSameType(other: RecyclerAdapterView<*>): Boolean {
        val otherCard = other as? DocumentationCardWithButtonRow ?: return false
        return otherCard.data.title == data.title
    }
}

fun DocumentationCardWithButtonRow.isPersonalDocumentationRow() =
    (data.title as? TextResourceModel)?.textRes == R.string.more_documentation_send_data_title
