/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.documentation

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.appcompat.app.AlertDialog
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.recyclerview.widget.LinearLayoutManager
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import com.google.android.material.snackbar.Snackbar
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentDocumentationBinding
import dk.nsp.mingraviditet.domain.AlertDialogButtonModel
import dk.nsp.mingraviditet.domain.AlertDialogViewModel
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.createAndShowWith
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled

@AndroidEntryPoint
class DocumentationFragment : Fragment() {

    private val adapter by lazy {
        DelegatingListAdapter(viewLifecycleOwner)
    }

    private val viewModel by viewModels<DocumentationViewModel>()

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        val binding = FragmentDocumentationBinding.inflate(inflater, container, false)
        binding.lifecycleOwner = viewLifecycleOwner
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }
        binding.toolbar.setTitle(R.string.more_documentation_title)

        binding.recyclerView.adapter = adapter

        viewModel.rowsToShow.observe(viewLifecycleOwner) { items ->
            adapter.submitList(items)
        }

        viewModel.scrollToPosition.observeIfNotHandled(viewLifecycleOwner) {
            it?.let { position ->
                binding.recyclerView.post {
                    (binding.recyclerView.layoutManager as? LinearLayoutManager)?.scrollToPositionWithOffset(
                        position,
                        // Try to scroll the view to the top
                        0,
                    )
                }
            }
        }

        viewModel.onDocumentSent.observeIfNotHandled(viewLifecycleOwner) { success ->
            if (success) {
                AlertDialog.Builder(binding.root.context).createAndShowWith(
                    AlertDialogViewModel(
                        title = R.string.more_documentation_pdf_sent_alert_title,
                        message = R.string.more_documentation_pdf_sent_alert_description,
                        positiveButton = AlertDialogButtonModel(R.string.common_cta_close),
                    ),
                )
            } else {
                Snackbar.make(
                    binding.root,
                    R.string.more_documentation_pdf_error_description,
                    Snackbar.LENGTH_LONG,
                ).show()
            }
        }

        return binding.root
    }
}
