/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.settings

import android.annotation.SuppressLint
import android.os.Bundle
import android.view.LayoutInflater
import android.view.MotionEvent
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import com.commonsense.android.kotlin.views.extensions.gone
import com.commonsense.android.kotlin.views.extensions.visible
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentConsentBinding
import dk.nsp.mingraviditet.util.android.OpenExternalLinksInBrowserWebViewClient
import dk.nsp.mingraviditet.util.android.WebViewHelper
import dk.nsp.mingraviditet.util.android.WebViewHelper.setUpDarkModeSupport
import dk.nsp.mingraviditet.util.extensions.navigateSafe

@AndroidEntryPoint
class ConsentFragment : Fragment() {

    private val targetBaseUrl = "file:///android_asset/"

    private val webViewViewModel by viewModels<SettingsPageViewModel>()

    private var binding: FragmentConsentBinding? = null

    @SuppressLint("ClickableViewAccessibility")
    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View? {
        binding = FragmentConsentBinding.inflate(inflater, container, false).apply {
            toolbar.setNavigationOnClickListener { onBackPressed() }
            toolbar.setTitle(R.string.settings_consent_title)

            webView.webViewClient =
                OpenExternalLinksInBrowserWebViewClient(root.context, ::onWebViewPageFinished)

            webView.isVerticalScrollBarEnabled = false
            webView.setUpDarkModeSupport()
            webView.setOnTouchListener { _, event -> (event?.action == MotionEvent.ACTION_MOVE) }

            removeConsent.setOnClickListener {
                // Present bottom sheet
                findNavController().navigateSafe(ConsentFragmentDirections.actionConsentFragmentToRemoveConsentBottomSheet())
            }

            webViewViewModel.onContent.observe(viewLifecycleOwner) {
                val htmlToLoad = WebViewHelper.createHtmlWithStyleSheet(it, root.context)
                webView.loadDataWithBaseURL(
                    targetBaseUrl,
                    htmlToLoad,
                    "text/html",
                    "UTF-8",
                    "",
                )
            }
        }
        binding?.lifecycleOwner = viewLifecycleOwner

        return binding?.root
    }

    private fun onWebViewPageFinished(url: String?) {
        if (url?.startsWith(targetBaseUrl) == true) {
            binding?.loadingSpinner?.root?.gone()
            binding?.removeConsent?.visible()
        }
    }
}
