/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.settings

import android.annotation.SuppressLint
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.navArgs
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import com.commonsense.android.kotlin.views.extensions.disable
import com.commonsense.android.kotlin.views.extensions.gone
import com.commonsense.android.kotlin.views.extensions.visible
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentWebviewBinding
import dk.nsp.mingraviditet.util.android.OpenExternalLinksInBrowserWebViewClient
import dk.nsp.mingraviditet.util.android.WebViewHelper
import dk.nsp.mingraviditet.util.android.WebViewHelper.setUpDarkModeSupport
import dk.nsp.util.textmodel.TextModel

@AndroidEntryPoint
class SettingSubPageWebViewFragment : Fragment() {

    private val args by navArgs<SettingSubPageWebViewFragmentArgs>()

    private val webViewViewModel by viewModels<SettingsPageViewModel>()

    @SuppressLint("ClickableViewAccessibility")
    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        val binding = FragmentWebviewBinding.inflate(inflater, container, false)
        binding.lifecycleOwner = viewLifecycleOwner
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }
        binding.toolbar.setTitle(args.titleRes)

        binding.webView.webViewClient =
            OpenExternalLinksInBrowserWebViewClient(binding.root.context) {
                binding.loadingSpinner.root.gone()
            }

        binding.webView.setUpDarkModeSupport()
        binding.webView.disable()
        binding.webView.isVerticalScrollBarEnabled = false
        binding.webView.isScrollbarFadingEnabled = false

        webViewViewModel.onErrorLoadingUrl.observe(viewLifecycleOwner) {
            binding.loadingSpinner.root.gone()
            binding.errorState.apply {
                root.visible()

                titleText = TextModel.from(R.string.common_alert_title_error)
                descriptionText = TextModel.from(R.string.common_alert_message_failed_to_load_data)
            }
        }

        webViewViewModel.onContent.observe(viewLifecycleOwner) {
            val htmlToLoad = WebViewHelper.createHtmlWithStyleSheet(it, binding.root.context)
            binding.webView.loadDataWithBaseURL(
                "file:///android_asset/",
                htmlToLoad,
                "text/html",
                "UTF-8",
                "",
            )
        }

        return binding.root
    }
}
