/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.settings

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.commonsense.android.kotlin.base.extensions.coroutines.launchIO
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.domain.SettingSubSectionUrl
import dk.nsp.domain.repository.SettingsPagesRepository
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import javax.inject.Inject

@HiltViewModel
class SettingsPageViewModel @Inject constructor(
    private val pagesRepository: SettingsPagesRepository,
    private val savedStateHandle: SavedStateHandle,
) : ViewModel() {

    private var page = savedStateHandle.get<SettingSubSectionUrl>("page")

    private val _onContent = MutableLiveData<String>()
    val onContent: LiveData<String> = _onContent

    private val _onErrorLoadingUrl = MutableLiveData<Unit>()
    val onErrorLoadingUrl: LiveData<Unit> = _onErrorLoadingUrl

    init {
        refreshPage()
    }

    private fun refreshPage() {
        viewModelScope.launchIO {
            page?.let {
                when (val pageResult = pagesRepository.getPage(this, it).await()) {
                    is Success -> _onContent.postValue(pageResult.value.content)
                    is Failed -> _onErrorLoadingUrl.postValue(Unit)
                }
            }
        }
    }

    fun setPage(newPage: SettingSubSectionUrl) {
        page = newPage
        refreshPage()
    }
}
