/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.support

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import com.commonsense.android.kotlin.system.extensions.onBackPressed
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentJournalKeyValueSectionOverviewBinding
import dk.nsp.mingraviditet.ui.main.more.MoreSection
import dk.nsp.mingraviditet.ui.widgets.HeaderViewWithIconBindingModel
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.navigateSafe
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled

@AndroidEntryPoint
class SupportOverviewFragment : Fragment() {

    private val viewModel by viewModels<SupportViewModel>()

    private val adapter by lazy {
        DelegatingListAdapter(viewLifecycleOwner)
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?,
    ): View {
        val binding =
            FragmentJournalKeyValueSectionOverviewBinding.inflate(inflater, container, false)
        binding.lifecycleOwner = viewLifecycleOwner
        binding.toolbar.setNavigationOnClickListener { onBackPressed() }
        binding.toolbar.setTitle(R.string.more_support_title)

        binding.recyclerView.adapter = adapter

        binding.headerModel = HeaderViewWithIconBindingModel(
            MoreSection.Support.getTitle(),
            MoreSection.Support.getDescription(),
            MoreSection.Support.getIcon(),
        )

        viewModel.rowsToShow.observe(viewLifecycleOwner) {
            adapter.submitList(it)
        }

        viewModel.onNavigateToSection.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(it)
        }

        return binding.root
    }
}
