/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.support

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.navigation.NavDirections
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.domain.SettingSubSectionUrl
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.ui.main.journal.sections.JournalSectionCardItem
import dk.nsp.mingraviditet.ui.main.journal.sections.SectionCardListItemBindingModel
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView
import dk.nsp.mingraviditet.util.livedata.SingleEvent
import dk.nsp.util.textmodel.TextModel
import javax.inject.Inject

@HiltViewModel
class SupportViewModel @Inject constructor() : ViewModel() {

    private val _rowsToShow = MutableLiveData<List<RecyclerAdapterView<*>>>()
    val rowsToShow: LiveData<List<RecyclerAdapterView<*>>> = _rowsToShow

    private val _onNavigateToSection: MutableLiveData<SingleEvent<NavDirections>> =
        MutableLiveData()
    val onNavigateToSection: LiveData<SingleEvent<NavDirections>> = _onNavigateToSection

    init {
        _rowsToShow.postValue(createOverviewRows())
    }

    private fun createOverviewRows(): List<RecyclerAdapterView<*>> {
        return listOf(
            JournalSectionCardItem(
                SectionCardListItemBindingModel(
                    TextModel.Companion.from(R.string.more_support_faq_title),
                    false,
                ) {
                    _onNavigateToSection.postValue(SingleEvent(SupportOverviewFragmentDirections.actionSupportOverviewFragmentToFAQFragment()))
                },
            ),
            JournalSectionCardItem(
                SectionCardListItemBindingModel(
                    text = TextModel.Companion.from(R.string.more_support_contact_title),
                    isLastItem = true,
                ) {
                    _onNavigateToSection.postValue(
                        SingleEvent(
                            SupportOverviewFragmentDirections.actionSupportOverviewFragmentToWebViewFragment(
                                SettingSubSectionUrl.Support,
                                R.string.more_support_contact_title,
                            ),
                        ),
                    )
                },
            ),
        )
    }
}
