/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.useradmission

import android.os.Bundle
import android.view.LayoutInflater
import androidx.activity.viewModels
import androidx.appcompat.app.AppCompatActivity
import androidx.core.splashscreen.SplashScreen.Companion.installSplashScreen
import androidx.navigation.fragment.NavHostFragment
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.ActivityUserAdmissionBinding
import dk.nsp.mingraviditet.extensions.adjustForNavigationBarInsets
import dk.nsp.mingraviditet.ui.useradmission.onboarding.OnboardingFragmentDirections
import dk.nsp.mingraviditet.util.extensions.navigateSafe

@AndroidEntryPoint
class UserAdmissionActivity : AppCompatActivity() {

    private val userAdmissionViewModel by viewModels<UserAdmissionViewModel>()

    override fun onCreate(savedInstanceState: Bundle?) {
        installSplashScreen()

        super.onCreate(savedInstanceState)
        val binding = ActivityUserAdmissionBinding.inflate(LayoutInflater.from(this))
        setContentView(binding.root)

        if (savedInstanceState != null) {
            return
        }

        if (userAdmissionViewModel.hasSeenAgreement) {
            val navHostFragment = supportFragmentManager.findFragmentById(R.id.user_admission_nav_host_fragment) as NavHostFragment
            val navController = navHostFragment.navController
            navController.navigateSafe(
                OnboardingFragmentDirections.actionOnboardingFragmentToMainActivity(),
            )
            finish()
        }

        // The whole content view needs to be insets from the bottom, since
        binding.root.adjustForNavigationBarInsets()
    }
}
