/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.useradmission.onboarding

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.ViewOnboardingPageBinding
import dk.nsp.mingraviditet.util.extensions.getDrawableFromAttr

class OnboardingPageAdapter : RecyclerView.Adapter<OnboardingPageViewHolder>() {
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): OnboardingPageViewHolder {
        val binding = ViewOnboardingPageBinding.inflate(
            LayoutInflater.from(parent.context),
            parent,
            false,
        )

        parent.context.getDrawableFromAttr(R.attr.onboardingPageOne)
        return OnboardingPageViewHolder(binding)
    }

    override fun onBindViewHolder(holder: OnboardingPageViewHolder, position: Int) {
        val pageModels = listOf(
            OnboardingPage(
                R.string.onboarding_overview_title,
                R.string.onboarding_overview_text,
                holder.itemView.context.getDrawableFromAttr(R.attr.onboardingPageOne),
            ),
            OnboardingPage(
                R.string.onboarding_appointments_title,
                R.string.onboarding_appointments_text,
                holder.itemView.context.getDrawableFromAttr(R.attr.onboardingPageTwo),
            ),
            OnboardingPage(
                R.string.onboarding_knowledge_title,
                R.string.onboarding_knowledge_text,
                holder.itemView.context.getDrawableFromAttr(R.attr.onboardingPageThree),
            ),
        )
        holder.bind(pageModels[position])
    }

    override fun getItemCount(): Int = 3
}
