/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.widgets

import android.view.animation.Animation
import android.view.animation.AnimationUtils
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.ViewPinInputFieldsBinding
import dk.nsp.mingraviditet.util.extensions.bindingadapters.setTextModel
import dk.nsp.util.textmodel.TextModel

class PinCodeInputDelegate(
    private val binding: ViewPinInputFieldsBinding,
) {

    private val animationDelay = 100L

    private val pinCodeBoxes = listOf(
        binding.pinCodeField1,
        binding.pinCodeField2,
        binding.pinCodeField3,
        binding.pinCodeField4,
    )

    init {
        updatePins("")
    }

    fun updatePins(pin: String) {
        pinCodeBoxes.forEachIndexed { index, pinField ->
            when {
                index < pin.length -> pinField.updateForState(PinState.Filled, true)
                index == pin.length -> pinField.updateForState(PinState.Highlighted, true)
                else -> pinField.updateForState(PinState.Default, true)
            }
        }
    }

    fun hideAndStartLoading() {
        binding.errorMessage.setTextModel(null)
        pinCodeBoxes.forEach {
            if (it.getState() != PinState.Filled) {
                it.updateForState(PinState.Filled, true)
            }
        }

        pinCodeBoxes.forEachIndexed { index, pinField ->
            pinField.updateForState(
                PinState.Loading,
                true,
                index * animationDelay,
            )
        }
    }

    fun animateForError(errorTextModel: TextModel?, endAction: () -> Unit) {
        pinCodeBoxes.forEach { pinField ->
            pinField.updateForState(PinState.Error, true)
        }
        val shake = AnimationUtils.loadAnimation(binding.root.context, R.anim.shake)
        shake.setAnimationListener(object : Animation.AnimationListener {
            override fun onAnimationRepeat(p0: Animation?) {}

            override fun onAnimationStart(p0: Animation?) {}

            override fun onAnimationEnd(p0: Animation?) {
                updatePins("")
                binding.errorMessage.setTextModel(errorTextModel)
                endAction()
            }
        })
        shake.duration = PinInputView.transitionDurationMs.toLong()

        binding.boxContainerWrapper.startAnimation(shake)
    }
}
