/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.android

import android.content.Context
import android.content.Intent
import android.net.Uri
import android.webkit.WebResourceRequest
import android.webkit.WebView
import android.webkit.WebViewClient
import com.commonsense.android.kotlin.system.systemIntegration.presentDialer
import dk.nsp.mingraviditet.util.extensions.composeEmail

/***
 * This webview client makes sure that external links gets opened outside of our app
 */
class OpenExternalLinksInBrowserWebViewClient(
    private val context: Context,
    private val onPageFinished: ((url: String?) -> Unit)? = null,
) : WebViewClient() {
    override fun shouldOverrideUrlLoading(view: WebView?, request: WebResourceRequest?): Boolean {
        val url = request?.url.toString()

        return if (url.startsWith("https://") || url.startsWith("http://")) {
            val i = Intent(Intent.ACTION_VIEW, Uri.parse(url))
            context.startActivity(i)
            true
        } else if (url.startsWith("tel:")) {
            val phoneNumber = url.substringAfter(':')
            context.presentDialer(phoneNumber)
            true
        } else if (url.startsWith("mailto:")) {
            val mailAddress = url.substringAfter(':')
            context.composeEmail(mailAddress, "Min Graviditet support")
            true
        } else {
            false
        }
    }

    override fun onPageFinished(view: WebView?, url: String?) {
        onPageFinished?.let {
            it(url)
        } ?: super.onPageFinished(view, url)
    }
}
