/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.android.motionlayout

import androidx.constraintlayout.motion.widget.MotionLayout
import dk.nsp.mingraviditet.R

enum class MotionLayoutStateEnum {
    Start, End
}

open class SimpleTransitionListener : MotionLayout.TransitionListener {

    private var currentState: MotionLayoutStateEnum = MotionLayoutStateEnum.Start
    var newStateCallback: ((MotionLayoutStateEnum) -> Unit)? = null

    fun getState(): MotionLayoutStateEnum {
        return currentState
    }

    override fun onTransitionStarted(
        p0: MotionLayout?,
        startState: Int,
        endState: Int,
    ) {
    }

    override fun onTransitionChange(
        p0: MotionLayout?,
        startState: Int,
        endState: Int,
        progress: Float,
    ) {
    }

    override fun onTransitionCompleted(p0: MotionLayout?, newState: Int) {
        when (newState) {
            R.id.start -> {
                onTransition(MotionLayoutStateEnum.Start)
            }
            R.id.end -> {
                onTransition(MotionLayoutStateEnum.End)
            }
        }
    }

    private fun onTransition(toolbarState: MotionLayoutStateEnum) {
        currentState = toolbarState
        newStateCallback?.invoke(toolbarState)
    }

    override fun onTransitionTrigger(
        p0: MotionLayout?,
        oldState: Int,
        newState: Boolean,
        progress: Float,
    ) {
    }
}
