/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.extensions

import androidx.appcompat.app.AlertDialog
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.domain.AlertDialogViewModel

fun AlertDialog.Builder.createAndShowWith(model: AlertDialogViewModel) {
    setTitle(model.title)

    var msg = context.getString(model.message)
    model.details?.let { problemDetails ->
        problemDetails.debugging?.let { debugging ->
            msg += "\n\n"
            msg += context.getString(R.string.error_handling_message, debugging)
        }
        problemDetails.detail?.let { details ->
            msg += "\n\n"
            msg += details
        }
    }

    setMessage(msg)

    setCancelable(model.cancelable)
    model.positiveButton?.let {
        setPositiveButton(it.buttonTitle, it.dialogInterface)
    }
    model.negativeButton?.let {
        setNegativeButton(it.buttonTitle, it.dialogInterface)
    }
    model.onDismissListener?.let {
        setOnDismissListener(it)
    }

    create().show()
}
