/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.extensions

import dk.nsp.mingraviditet.R
import dk.nsp.models.ObservationType
import dk.nsp.util.textmodel.TextModel
import dk.nsp.util.textmodel.TextResourceModel

fun ObservationType.isFetusObservation(): Boolean = when (this) {
    ObservationType.FetusActivity,
    ObservationType.FetusPresentation,
    ObservationType.FetusWeightEstimate,
    -> true
    else -> false
}

val ObservationType?.displayName: TextResourceModel
    get() = when (this) {
        ObservationType.Weight -> R.string.journal_section_measurements_table_mothers_weight
        ObservationType.BloodPressure -> R.string.journal_section_measurements_table_blood_pressure
        ObservationType.Urine -> R.string.journal_section_measurements_table_urine_sample
        ObservationType.Edema -> R.string.journal_section_measurements_table_edema
        ObservationType.PubisMeasurements -> R.string.journal_section_measurements_table_pubismeasurement
        ObservationType.FetusActivity -> R.string.journal_section_measurements_table_fetus_activity
        ObservationType.FetusWeightEstimate -> R.string.journal_section_measurements_table_estimated_fetus_weight
        ObservationType.FetusWeightEstimateUltrasound -> R.string.journal_section_scans_table_ultrasound_weight
        ObservationType.FetusPresentation,
        ObservationType.FetusPresentationUltrasound,
        -> R.string.journal_section_scans_table_fetus_presentation
        ObservationType.Cervix -> R.string.journal_section_scans_table_cervix
        ObservationType.Dvp -> R.string.journal_section_scans_table_dvp
        ObservationType.GestationAge,
        ObservationType.GestationAgeUltrasound,
        -> R.string.journal_section_scans_table_gestation_age
        ObservationType.WeightDeviation -> R.string.journal_section_scans_table_weight_deviation
        ObservationType.AmnioticFluid -> R.string.journal_section_scans_table_amniotic_fluid
        ObservationType.Flow -> R.string.journal_section_scans_table_flow
        null -> R.string.common_missing_data
    }.let {
        TextModel.from(it)
    }
