/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.extensions

import dk.nsp.mingraviditet.R
import dk.nsp.models.ProblemDetails
import dk.nsp.util.textmodel.TextModel

fun String?.toTextModelOrDefault(): TextModel {
    return if (this?.isNotBlank() == true) {
        TextModel.from(this)
    } else {
        TextModel.from(R.string.common_missing_data)
    }
}

fun Boolean?.toYesNoTextModelOrDefault(): TextModel {
    return when (this) {
        true -> TextModel.from(R.string.enum_yes)
        false -> TextModel.from(R.string.enum_no)
        else -> TextModel.from(R.string.common_missing_data)
    }
}

fun Int.toTextModel(): TextModel = TextModel.from("$this")

fun Int?.toTextModelOrDefault(): TextModel {
    return if (this != null) {
        TextModel.from("$this")
    } else {
        TextModel.from(R.string.common_missing_data)
    }
}

fun TextModel.withContactSupportText(problemDetails: ProblemDetails?): TextModel {
    val debugInfo = problemDetails?.debugging
    return if (debugInfo != null) {
        val textModels = mutableListOf(this)
        textModels.add(TextModel.from(R.string.error_handling_message, TextModel.from(debugInfo)))

        TextModel.from(textModels, TextModel.from("\n\n"))
    } else {
        this
    }
}
