/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2018 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.extensions.bindingadapters

import android.graphics.Typeface
import android.widget.TextView
import androidx.annotation.ColorRes
import androidx.annotation.StringRes
import androidx.core.content.ContextCompat
import androidx.databinding.BindingAdapter
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.util.extensions.getColorFromAttr
import dk.nsp.shared.tryAndLog
import dk.nsp.util.textmodel.TextModel

@BindingAdapter("safeText")
fun TextView.setSafeText(@StringRes nullableStringRes: Int?) {
    tryAndLog(message = "Failed to set string resource with id: $nullableStringRes") {
        if (nullableStringRes != null && nullableStringRes != 0) {
            setText(nullableStringRes)
        }
    }
}

@BindingAdapter("safeTextColor")
fun TextView.setSafeTextColor(@ColorRes nullableTextColor: Int?) {
    tryAndLog(message = "Failed to set textColor resource with id: $nullableTextColor") {
        if (nullableTextColor != null && nullableTextColor != 0) {
            setTextColor(ContextCompat.getColor(context, nullableTextColor))
        }
    }
}

@BindingAdapter("textModel")
fun TextView.setTextModel(model: TextModel?) {
    text = model?.getString(resources)
}

@BindingAdapter("textModelOrDefault")
fun TextView.setTextModelOrDefault(model: TextModel?) {
    val tm = model?.getString(resources) ?: "-"
    text = tm
}

@BindingAdapter("setClickableDictionaryStyle")
fun TextView.setClickableDictionaryStyle(dictionaryAvailable: Boolean) {
    if (dictionaryAvailable) {
        // Make key phat
        setTextColor(
            context.getColorFromAttr(
                android.R.attr.colorSecondary,
            ),
        )
        setTypeface(typeface, Typeface.BOLD)
    } else {
        // Default body style
        setTextColor(
            context.getColorFromAttr(
                R.attr.mgTextColor,
            ),
        )
        setTypeface(typeface, Typeface.NORMAL)
    }
}

fun TextView.isTextEllipsized(): Boolean {
    return layout?.let {
        val lineCount = it.lineCount
        it.getEllipsisCount(lineCount - 1) > 0
    } == true
}
