/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.domain

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.testextensions.assertResourceModel
import dk.nsp.mingraviditet.testextensions.assertStringModel
import dk.nsp.mingraviditet.util.extensions.getColorFromAttr
import dk.nsp.testassertions.assertEquals
import dk.nsp.util.textmodel.TextModel
import org.junit.Test
import org.junit.runner.RunWith
import org.robolectric.RobolectricTestRunner
import org.robolectric.RuntimeEnvironment
import org.robolectric.annotation.Config

@Config(sdk = [26], manifest = Config.NONE)
@RunWith(RobolectricTestRunner::class)
class InfoBoxModelTest {

    private val context
        get() = RuntimeEnvironment.getApplication()

    @Test
    fun getBackgroundColor() {
        val primary = InfoBoxModel.Primary(TextModel.from(R.string.common_show))
        primary.textModel.assertResourceModel(R.string.common_show)
        primary.getBackgroundColor(context).assertEquals(context.getColorFromAttr(R.attr.colorPrimary))

        val orangeWithoutModel = InfoBoxModel.Orange()
        orangeWithoutModel.textModel.assertResourceModel(R.string.journal_bottom_previous_info_text)

        val orangeWithModel = InfoBoxModel.Orange(TextModel.from(R.string.common_ok))
        orangeWithModel.textModel.assertResourceModel(R.string.common_ok)
        orangeWithModel.getBackgroundColor(context).assertEquals(context.getColor(R.color.tree_poppy))

        val unknown = InfoBoxModel.Unknown
        unknown.textModel.assertStringModel("")
        unknown.getBackgroundColor(context).assertEquals(context.getColor(android.R.color.transparent))
    }
}
