/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.extensions

import dk.nsp.mingraviditet.testData.ObservationEmpty
import dk.nsp.mingraviditet.testData.ObservationValuesEmpty
import dk.nsp.mingraviditet.testextensions.assertStringModel
import dk.nsp.models.ObservationType
import org.junit.jupiter.api.Test

class ObservationExtensionsTest {
    @Test
    fun observationGetMeasurementTextModel() {
        ObservationEmpty.copy(
            type = ObservationType.BloodPressure,
            propertyValues = listOf(
                ObservationValuesEmpty.copy(
                    "10",
                ),
                ObservationValuesEmpty.copy(
                    "30",
                ),
            ),
        ).getMeasurementTextModel().assertStringModel("10/30")

        ObservationEmpty.copy(
            type = ObservationType.GestationAge,
            propertyValues = listOf(
                ObservationValuesEmpty.copy(
                    value = "17",
                    unit = "kg",
                ),
                ObservationValuesEmpty.copy(
                    "1997",
                ),
            ),
        ).getMeasurementTextModel().assertStringModel("17 kg | 1997")

        ObservationEmpty.copy(
            type = null,
            propertyValues = listOf(
                ObservationValuesEmpty.copy(
                    "NoType",
                ),
            ),
        ).getMeasurementTextModel().assertStringModel("NoType")
    }
}
