/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.testData

import dk.nsp.models.Address
import dk.nsp.models.CprIdentifiedPerson
import dk.nsp.models.DataCard
import dk.nsp.models.DataCardAllOfScreeningsSection
import dk.nsp.models.ExpectedDateOfDeliverySection
import dk.nsp.models.ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriod
import dk.nsp.models.ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycle
import dk.nsp.models.HealthCareOrganization
import dk.nsp.models.HealthCarePerformer
import dk.nsp.models.HealthInsuranceSection
import dk.nsp.models.MaternalAntibodyScreeningSection
import dk.nsp.models.MaternalRhDScreeningSection
import dk.nsp.models.MultiplePregnancySection
import dk.nsp.models.Note
import dk.nsp.models.Observation
import dk.nsp.models.ObservationValues
import dk.nsp.models.Person
import dk.nsp.models.PersonName
import dk.nsp.models.PersonalDataSectionGeneralPractitioner
import dk.nsp.models.PersonalDataSectionTemporaryAddress
import dk.nsp.models.PositiveNegativeScreeningWithDateSection
import dk.nsp.models.PrimaryPlannedBirthPlaceSection
import dk.nsp.models.RevisedPlannedBirthPlaceSection
import dk.nsp.models.WeeklyAlcoholUnitsConsumption
import dk.nsp.models.WeeklyConsumptionDuringPregnancy
import dk.nsp.models.WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRisk
import java.time.LocalDateTime

/*
 * Convenience fields in here are used to avoid large constructors in test and to be able to .copy(...) and replace fields under test
 */

val DataCardEmpty by lazy {
    DataCard(
        episodeOfCareIdentifier = "",
        recordTarget = CprIdentifiedPersonEmpty.copy(),
        modifiedTime = null,
        author = null,
        dirty = null,
        documentUniqueId = null,
        version = null,
        documentStatus = null,
        closeDateTime = null,
        childPartnerSection = null,
        languageSection = null,
        bodyMeasuresSection = null,
        socialHistorySection = null,
        previousBirthsSection = null,
        previousAbortionsSection = null,
        expectedDateOfDeliverySection = null,
        ultrasoundSection = null,
        prenatalRiskAssessmentSection = null,
        workEnvironmentImpactSection = null,
        allergiesSection = null,
        screeningsSection = null,
        chronicDiseasesSection = null,
        medicineSection = null,
        mmrVaccinationSection = null,
        historyOfPreviousTreatmentWithImpactOnPregnancySection = null,
        tobaccoUseAndExposureSection = null,
        alcoholDrinkingBehaviorSection = null,
        assistedFertilizationSection = null,
        substanceUseSection = null,
        dietaryAndExerciseSection = null,
        healthInsuranceSection = null,
        desiredBirthPlaceSection = null,
        primaryPlannedBirthPlaceSection = null,
        revisedPlannedBirthPlaceSection = null,
        midwifeClinicSection = null,
        midwifeConsultationSection = null,
        overallAssessmentSection = null,
        multiplePregnancySection = null,
        personalDataSection = null,
        healthcareSection = null,
    )
}

val CprIdentifiedPersonEmpty by lazy {
    CprIdentifiedPerson(
        name = null,
        identifier = null,
    )
}

val PersonEmpty by lazy {
    Person(
        PersonNameEmpty,
    )
}

val PersonNameEmpty by lazy {
    PersonName(
        prefixName = null,
        firstNames = null,
        middleNames = null,
        lastName = null,
    )
}

val PersonalDataSectionTemporaryAddressEmpty by lazy {
    PersonalDataSectionTemporaryAddress(
        null,
        null,
        null,
        null,
        null,
    )
}

val PrimaryPlannedBirthPlaceSectionEmpty by lazy {
    PrimaryPlannedBirthPlaceSection(
        modifiedTime = null,
        author = null,
        dirty = null,
        primaryPlannedBirthPlace = null,
    )
}

val RevisedPlannedBirthPlaceSectionEmpty by lazy {
    RevisedPlannedBirthPlaceSection(
        modifiedTime = null,
        author = null,
        dirty = null,
        revisedPlannedBirthPlace = null,
    )
}

val HealthCareOrganizationEmpty by lazy {
    HealthCareOrganization(
        name = "",
        sorId = "",
    )
}

val PersonalDataSectionGeneralPractitionerEmpty by lazy {
    PersonalDataSectionGeneralPractitioner(
        null,
        null,
        null,
    )
}

val AddressEmpty by lazy {
    Address(
        null,
        null,
        null,
    )
}

val HealthInsuranceSectionEmpty by lazy {
    HealthInsuranceSection(
        HealthInsuranceSection.InsuranceGroup._1,
        null,
        null,
        null,
        null,
        null,
        null,
    )
}

val ExpectedDateOfDeliverySectionEmpty by lazy {
    ExpectedDateOfDeliverySection(
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
    )
}

val ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodEmpty by lazy {
    ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriod(
        null,
        null,
        null,
        null,
    )
}

val ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty by lazy {
    ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycle(
        null,
        null,
    )
}

val WeeklyAlcoholUnitsConsumptionEmpty by lazy {
    WeeklyAlcoholUnitsConsumption(
        null,
        null,
    )
}

val WeeklyConsumptionDuringPregnancyEmpty by lazy {
    WeeklyConsumptionDuringPregnancy(
        null,
        null,
        null,
        null,
        null,
    )
}

val WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRiskEmpty by lazy {
    WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRisk(
        null,
        null,
        null,
        null,
        null,
    )
}

val NoteEmpty by lazy {
    Note(
        "",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
    )
}

val MultiplePregnancySectionEmpty by lazy {
    MultiplePregnancySection(
        null,
        null,
        null,
        null,
    )
}

val HealthCarePerformerEmpty by lazy {
    HealthCarePerformer(
        null,
        null,
        null,
        null,
        null,
    )
}

val ObservationEmpty by lazy {
    Observation(
        dateOfMeasurement = LocalDateTime.of(1970, 1, 1, 0, 0),
        propertyValues = emptyList(),
        measuredBy = HealthCarePerformerEmpty,
        fetus = null,
        activityReference = null,
        type = null,
        id = null,
    )
}

val ObservationValuesEmpty by lazy {
    ObservationValues(
        value = "",
        unit = null,
        name = null,
    )
}

val DataCardAllOfScreeningsSectionEmpty by lazy {
    DataCardAllOfScreeningsSection(
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
    )
}

val MaternalRhDScreeningSectionEmpty by lazy {
    MaternalRhDScreeningSection(
        null,
        null,
        null,
        null,
    )
}

val PositiveNegativeScreeningWithDateSectionEmpty by lazy {
    PositiveNegativeScreeningWithDateSection(
        null,
        null,
        null,
        null,
        null,
    )
}

val MaternalAntibodyScreeningSectionEmpty by lazy {
    MaternalAntibodyScreeningSection(
        null,
        null,
        null,
        null,
    )
}
