/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.testextensions.assertResourceModel
import dk.nsp.testassertions.assertEquals
import org.junit.jupiter.api.Test

class JournalSectionTest {
    @Test
    fun getTitle() {
        JournalSection.Measurements.getTitle().assertResourceModel(R.string.journal_section_measurements_title)
        JournalSection.Scans.getTitle().assertResourceModel(R.string.journal_section_scans_title)
        JournalSection.Screenings.getTitle().assertResourceModel(R.string.journal_section_screenings_title)
        JournalSection.JournalNotes.getTitle().assertResourceModel(R.string.journal_section_journal_notes_title)
        JournalSection.AroundThePregnancy.getTitle().assertResourceModel(R.string.journal_section_around_the_pregnancy_title)
        JournalSection.OverallAssessment.getTitle().assertResourceModel(R.string.journal_section_overall_assessment_title)
        JournalSection.HealthCare.getTitle().assertResourceModel(R.string.journal_section_health_care_title)
        JournalSection.PersonalData.getTitle().assertResourceModel(R.string.journal_section_personal_data_title)
    }

    @Test
    fun getDescription() {
        JournalSection.Measurements.getDescription().assertResourceModel(R.string.journal_section_measurements_description)
        JournalSection.Scans.getDescription().assertResourceModel(R.string.journal_section_scans_description)
        JournalSection.Screenings.getDescription().assertResourceModel(R.string.journal_section_screenings_description)
        JournalSection.JournalNotes.getDescription().assertResourceModel(R.string.journal_section_journal_notes_description)
        JournalSection.AroundThePregnancy.getDescription().assertResourceModel(R.string.journal_section_around_the_pregnancy_description)
        JournalSection.OverallAssessment.getDescription().assertResourceModel(R.string.journal_section_overall_assessment_description)
        JournalSection.HealthCare.getDescription().assertResourceModel(R.string.journal_section_health_care_description)
        JournalSection.PersonalData.getDescription().assertResourceModel(R.string.journal_section_personal_data_description)
    }

    @Test
    fun getIcon() {
        JournalSection.Measurements.getIcon().assertEquals(R.drawable.ic_measurements)
        JournalSection.Scans.getIcon().assertEquals(R.drawable.ic_scans)
        JournalSection.Screenings.getIcon().assertEquals(R.drawable.ic_screenings)
        JournalSection.JournalNotes.getIcon().assertEquals(R.drawable.ic_journal_notes)
        JournalSection.AroundThePregnancy.getIcon().assertEquals(R.drawable.ic_around_the_pregnancy)
        JournalSection.OverallAssessment.getIcon().assertEquals(R.drawable.ic_riskassessment)
        JournalSection.HealthCare.getIcon().assertEquals(R.drawable.ic_healthcare)
        JournalSection.PersonalData.getIcon().assertEquals(R.drawable.ic_personal)
    }

    @Test
    fun createJournalSectionCardBindingModel() {
        val model = JournalSection.Measurements.createJournalSectionCardBindingModel({})

        model.title.assertResourceModel(R.string.journal_section_measurements_title)
        model.description.assertResourceModel(R.string.journal_section_measurements_description)
        model.icon.assertEquals(R.drawable.ic_measurements)
    }
}
