/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.extensions

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.testextensions.assertResourceModel
import dk.nsp.mingraviditet.testextensions.assertStringModel
import dk.nsp.models.DateValueUnitScreeningSection
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIsAndApply
import dk.nsp.util.textmodel.TextCompositeModel
import org.junit.jupiter.api.Test
import java.math.BigDecimal

class DateValueUnitScreeningSectionExtensionsTest {

    class DateValueUnitScreeningSectionToTextModel {
        @Test
        fun full() {
            DateValueUnitScreeningSection(
                value = BigDecimal.valueOf(10.8),
                unit = "units",
            ).toTextModel().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(expected = " ")

                bindings.size.assertEquals(2)
                bindings.getOrNull(0).assertStringModel(expected = "10.8")

                bindings.getOrNull(1).assertStringModel(expected = "units")
            }
        }

        @Test
        fun onlyValue() {
            DateValueUnitScreeningSection(
                value = BigDecimal.valueOf(700),
                unit = null,
            ).toTextModel().assertStringModel(expected = "700")
        }

        @Test
        fun onlyUnit() {
            DateValueUnitScreeningSection(
                value = null,
                unit = "rounds",
            ).toTextModel().assertResourceModel(expected = R.string.common_missing_data)
        }

        @Test
        fun nulls() {
            DateValueUnitScreeningSection(
                value = null,
                unit = null,
            ).toTextModel().assertResourceModel(expected = R.string.common_missing_data)

            val nullable: DateValueUnitScreeningSection? = null
            nullable.toTextModel().assertResourceModel(expected = R.string.common_missing_data)
        }
    }
}
