/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.extensions

import dk.nsp.mingraviditet.testData.HealthInsuranceSectionEmpty
import dk.nsp.mingraviditet.testData.PersonNameEmpty
import dk.nsp.models.Address
import dk.nsp.models.Person
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertNull
import org.junit.jupiter.api.Test

class HealthInsuranceSectionExtensionsTest {

    class HealthInsuranceSectionToGeneralPractionerData {
        @Test
        fun fullValue() {
            val address = Address(
                streetAndNumber = "Testvej 4",
                city = "Aarhus",
                zip = "8000",
            )

            val result = HealthInsuranceSectionEmpty
                .copy(
                    generalPractitioner = Person(
                        PersonNameEmpty.copy(
                            "Hr.",
                            listOf("Søren", "Preben"),
                            listOf("Humle"),
                            "Hansen",
                        ),
                    ),
                    generalPractitionerAddress = address,
                    generalPractitionerTelephoneNumber = "12345678",
                )
                .toGeneralPractionerData()

            result.name.assertEquals("Søren Preben Humle Hansen")
            result.address.assertEquals(address)
            result.telephoneNumber.assertEquals("12345678")
        }

        @Test
        fun nulls() {
            val result = HealthInsuranceSectionEmpty
                .copy(
                    generalPractitioner = null,
                    generalPractitionerAddress = null,
                    generalPractitionerTelephoneNumber = null,
                )
                .toGeneralPractionerData()

            result.name.assertNull()
            result.address.assertNull()
            result.telephoneNumber.assertNull()
        }
    }
}
