/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.extensions

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.testextensions.assertResourceModel
import dk.nsp.mingraviditet.testextensions.assertStringModel
import dk.nsp.models.UnitEnum
import dk.nsp.testassertions.assertEquals
import org.junit.jupiter.api.Test

class UnitEnumExtensionsTest {
    @Test
    fun unitEnumToTextModel() {
        UnitEnum.Cm.toTextModel().assertStringModel("cm")
        UnitEnum.KgSlashM2.toTextModel().assertStringModel("kg/m2")
        UnitEnum.G.toTextModel().assertStringModel("g")
        UnitEnum.W.toTextModel().assertResourceModel(R.string.common_unit_weeks)
        UnitEnum.HSlashWk.toTextModel().assertStringModel("h/wk")
        UnitEnum.D.toTextModel().assertStringModel("d")
        UnitEnum.GSlashWk.toTextModel().assertStringModel("g/wk")
        UnitEnum.Kg.toTextModel().assertStringModel("kg")

        UnitEnum.values().size.assertEquals(8, "Number of UnitEnums has changed, ensure that all cases has been tested")
    }
}
