/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.sectiondetails.aroundthepregnancy

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.testData.ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodEmpty
import dk.nsp.mingraviditet.testData.ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty
import dk.nsp.mingraviditet.testData.WeeklyAlcoholUnitsConsumptionEmpty
import dk.nsp.mingraviditet.testData.WeeklyConsumptionDuringPregnancyEmpty
import dk.nsp.mingraviditet.testData.WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRiskEmpty
import dk.nsp.mingraviditet.testextensions.assertResourceModel
import dk.nsp.mingraviditet.testextensions.assertStringModel
import dk.nsp.models.ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriod
import dk.nsp.models.ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycle
import dk.nsp.models.IntegerValueWithUnitEnum
import dk.nsp.models.UnitEnum
import dk.nsp.models.WeeklyAlcoholUnitsConsumption
import dk.nsp.models.WeeklyConsumptionDuringPregnancy
import dk.nsp.models.WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRisk
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIsAndApply
import dk.nsp.util.textmodel.TextCompositeModel
import dk.nsp.util.textmodel.TextModel
import dk.nsp.util.textmodel.TextResourceQuantityModel
import org.junit.jupiter.api.Test
import java.math.BigDecimal
import java.time.LocalDateTime

class AroundThePregnancyBllTest {

    @Test
    fun expectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodLastFirstDayOfCycleToTextModel() {
        ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodEmpty.copy(
            lastPeriod = LocalDateTime.of(2020, 5, 6, 10, 43),
        ).lastFirstDayOfCycleToTextModel().assertStringModel("06.05.2020")

        val nullable: ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriod? = null
        nullable.lastFirstDayOfCycleToTextModel().assertResourceModel(R.string.common_missing_data)

        val nullDate =
            ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodEmpty.copy(
                lastPeriod = null,
            )
        nullDate.lastFirstDayOfCycleToTextModel().assertResourceModel(R.string.common_missing_data)
    }

    @Test
    fun expectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodGetCalculatedExpectedDeliveryDate() {
        ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodEmpty.copy(
            expectedDateOfDelivery = LocalDateTime.of(2020, 2, 25, 10, 43),
        ).getCalculatedExpectedDeliveryDate().assertStringModel("25.02.2020")

        val nullable: ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriod? = null
        nullable.getCalculatedExpectedDeliveryDate()
            .assertResourceModel(R.string.common_missing_data)

        val nullDate =
            ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodEmpty.copy(
                expectedDateOfDelivery = null,
            )
        nullDate.getCalculatedExpectedDeliveryDate()
            .assertResourceModel(R.string.common_missing_data)
    }

    class ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleToTextModel {
        @Test
        fun bothValues() {
            ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty.copy(
                min = IntegerValueWithUnitEnum(10),
                max = IntegerValueWithUnitEnum(300),
            ).toTextModel().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" - ")

                bindings.size.assertEquals(2)
                bindings.getOrNull(0).assertStringModel("10")
                bindings.getOrNull(1).assertStringModel("300")
            }
        }

        @Test
        fun onlyMin() {
            ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty.copy(
                min = IntegerValueWithUnitEnum(20),
                max = null,
            ).toTextModel().assertStringModel("20")

            ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty.copy(
                min = IntegerValueWithUnitEnum(value = 30),
                max = IntegerValueWithUnitEnum(value = null),
            ).toTextModel().assertStringModel("30")
        }

        @Test
        fun onlyEnd() {
            ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty.copy(
                min = null,
                max = IntegerValueWithUnitEnum(1000),
            ).toTextModel().assertStringModel("1000")

            ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty.copy(
                min = IntegerValueWithUnitEnum(value = null),
                max = IntegerValueWithUnitEnum(value = 300),
            ).toTextModel().assertStringModel("300")
        }

        @Test
        fun nulls() {
            val nullable: ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycle? =
                null
            nullable.toTextModel().assertStringModel("")

            val allNulls =
                ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriodMenstrualCycleEmpty.copy(
                    min = null,
                    max = null,
                )
            allNulls.toTextModel().assertStringModel("")
        }
    }

    class WeeklyAlcoholUnitsConsumptionGetConsumption {
        @Test
        fun withValueAndUnit() {
            WeeklyAlcoholUnitsConsumptionEmpty.copy(
                consumption = IntegerValueWithUnitEnum(
                    value = 10,
                    unit = UnitEnum.GSlashWk,
                ),
            ).getConsumption().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" ")

                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertStringModel("10")
                bindings.getOrNull(1).assertStringModel("g/wk")
            }
        }

        @Test
        fun withOnlyValue() {
            WeeklyAlcoholUnitsConsumptionEmpty.copy(
                consumption = IntegerValueWithUnitEnum(
                    value = 10,
                    unit = null,
                ),
            ).getConsumption().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(10)

                pluralStringRes.assertEquals(R.plurals.alcohol_units)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    getOrNull(0).assertStringModel("10")
                }
            }
        }

        @Test
        fun withOnlyUnit() {
            WeeklyAlcoholUnitsConsumptionEmpty.copy(
                consumption = IntegerValueWithUnitEnum(
                    value = null,
                    unit = UnitEnum.GSlashWk,
                ),
            ).getConsumption().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" ")

                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertStringModel("0")
                bindings.getOrNull(1).assertStringModel("g/wk")
            }
        }

        @Test
        fun nulls() {
            val nullable: WeeklyAlcoholUnitsConsumption? = null
            nullable.getConsumption().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(0)

                pluralStringRes.assertEquals(R.plurals.alcohol_units)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    getOrNull(0).assertStringModel("0")
                }
            }

            val allNulls = WeeklyAlcoholUnitsConsumptionEmpty.copy(
                null,
            )
            allNulls.getConsumption().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(0)

                pluralStringRes.assertEquals(R.plurals.alcohol_units)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    getOrNull(0).assertStringModel("0")
                }
            }
        }
    }

    class WeeklyConsumptionDuringPregnancyGetAverageConsumption {
        @Test
        fun withValueAndUnit() {
            WeeklyConsumptionDuringPregnancyEmpty.copy(
                consumption = IntegerValueWithUnitEnum(
                    value = 10,
                    unit = UnitEnum.GSlashWk,
                ),
            ).getAverageConsumption().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" ")

                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertStringModel("10")
                bindings.getOrNull(1).assertStringModel("g/wk")
            }
        }

        @Test
        fun withOnlyValue() {
            WeeklyConsumptionDuringPregnancyEmpty.copy(
                consumption = IntegerValueWithUnitEnum(
                    value = 10,
                    unit = null,
                ),
            ).getAverageConsumption().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(10)

                pluralStringRes.assertEquals(R.plurals.alcohol_units)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    getOrNull(0).assertStringModel("10")
                }
            }
        }

        @Test
        fun withOnlyUnit() {
            WeeklyConsumptionDuringPregnancyEmpty.copy(
                consumption = IntegerValueWithUnitEnum(
                    value = null,
                    unit = UnitEnum.GSlashWk,
                ),
            ).getAverageConsumption().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" ")

                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertStringModel("0")
                bindings.getOrNull(1).assertStringModel("g/wk")
            }
        }

        @Test
        fun nulls() {
            val nullable: WeeklyConsumptionDuringPregnancy? = null
            nullable.getAverageConsumption().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(0)

                pluralStringRes.assertEquals(R.plurals.alcohol_units)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    getOrNull(0).assertStringModel("0")
                }
            }

            val allNulls = WeeklyConsumptionDuringPregnancyEmpty.copy(
                null,
            )
            allNulls.getAverageConsumption().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(0)

                pluralStringRes.assertEquals(R.plurals.alcohol_units)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    getOrNull(0).assertStringModel("0")
                }
            }
        }
    }

    class WeeklyConsumptionDuringPregnancyGetExcessiveDrinkingCount {
        @Test
        fun withValue() {
            WeeklyConsumptionDuringPregnancyEmpty.copy(
                excessiveDrinkingCount = BigDecimal.valueOf(10.4),
            ).getExcessiveDrinkingCount().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(10)
                pluralStringRes.assertEquals(R.plurals.excessive_drinking)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    firstOrNull().assertStringModel("10")
                }
            }
        }

        @Test
        fun nulls() {
            val nullable: WeeklyConsumptionDuringPregnancy? = null
            nullable.getExcessiveDrinkingCount().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(0)
                pluralStringRes.assertEquals(R.plurals.excessive_drinking)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    firstOrNull().assertStringModel("0")
                }
            }

            WeeklyConsumptionDuringPregnancyEmpty.copy(
                excessiveDrinkingCount = null,
            ).getExcessiveDrinkingCount().assertIsAndApply<TextResourceQuantityModel> {
                quantity.assertEquals(0)
                pluralStringRes.assertEquals(R.plurals.excessive_drinking)

                placeholderValues.assertIsAndApply<Array<TextModel>> {
                    size.assertEquals(1)
                    firstOrNull().assertStringModel("0")
                }
            }
        }
    }

    class WeeklyConsumptionDuringPregnancyGetExcessiveDrinkingWeeks {
        @Test
        fun multiple() {
            WeeklyConsumptionDuringPregnancyEmpty.copy(
                excessiveDrinkingWeeks = listOf(1, 3, 2),
            ).getExcessiveDrinkingWeeks().assertStringModel("1, 3, 2")
        }

        @Test
        fun single() {
            WeeklyConsumptionDuringPregnancyEmpty.copy(
                excessiveDrinkingWeeks = listOf(10),
            ).getExcessiveDrinkingWeeks().assertStringModel("10")
        }

        @Test
        fun nulls() {
            val nullable: WeeklyConsumptionDuringPregnancy? = null
            nullable.getExcessiveDrinkingWeeks().assertResourceModel(R.string.common_missing_data)

            WeeklyConsumptionDuringPregnancyEmpty.copy(
                excessiveDrinkingWeeks = null,
            ).getExcessiveDrinkingWeeks().assertResourceModel(R.string.common_missing_data)
        }
    }

    class WeeklyConsumptionDuringPregnancyGetTweakPoints {
        @Test
        fun withValue() {
            WeeklyConsumptionDuringPregnancyEmpty.copy(
                tweakPoints = WeeklyConsumptionDuringPregnancy.TweakPoints._4,
            ).getTweakPoints().assertStringModel("4")
        }

        @Test
        fun nulls() {
            val nullable: WeeklyConsumptionDuringPregnancy? = null
            nullable.getTweakPoints().assertResourceModel(R.string.common_missing_data)

            WeeklyConsumptionDuringPregnancyEmpty.copy(
                tweakPoints = null,
            ).getTweakPoints().assertResourceModel(R.string.common_missing_data)
        }
    }

    class WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRiskGetExposureDuration {
        @Test
        fun withBothDates() {
            WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRiskEmpty.copy(
                start = LocalDateTime.of(2020, 1, 2, 10, 34),
                end = LocalDateTime.of(2021, 2, 3, 14, 1),
            ).getExposureDuration().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" - ")
                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertStringModel("02.01.2020")
                bindings.getOrNull(1).assertStringModel("03.02.2021")
            }
        }

        @Test
        fun onlyStart() {
            WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRiskEmpty.copy(
                start = LocalDateTime.of(2020, 1, 2, 10, 34),
                end = null,
            ).getExposureDuration().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" - ")
                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertStringModel("02.01.2020")
                bindings.getOrNull(1).assertStringModel("")
            }
        }

        @Test
        fun onlyEnd() {
            WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRiskEmpty.copy(
                start = null,
                end = LocalDateTime.of(2021, 2, 3, 14, 1),
            ).getExposureDuration().assertIsAndApply<TextCompositeModel> {
                seperator.assertStringModel(" - ")
                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertStringModel("")
                bindings.getOrNull(1).assertStringModel("03.02.2021")
            }
        }

        @Test
        fun nulls() {
            val nullable: WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRisk? =
                null
            nullable.getExposureDuration().assertResourceModel(R.string.common_missing_data)

            WorkEnvironmentImpactSectionAllOfMotherExposureToWorkEnvironmentRiskEmpty.copy(
                start = null,
                end = null,
            ).getExposureDuration().assertResourceModel(R.string.common_missing_data)
        }
    }
}
