/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.journal.sections.sectiondetails.screenings

import dk.nsp.mingraviditet.testData.DataCardAllOfScreeningsSectionEmpty
import dk.nsp.mingraviditet.testData.MaternalAntibodyScreeningSectionEmpty
import dk.nsp.mingraviditet.testData.MaternalRhDScreeningSectionEmpty
import dk.nsp.mingraviditet.testextensions.assertStringModel
import dk.nsp.models.DataCardAllOfScreeningsSection
import dk.nsp.models.PosNegEnum
import dk.nsp.models.PositiveNegativeScreeningWithDateSection
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertNull
import org.junit.jupiter.api.Test
import java.time.LocalDateTime

class ScreeningsBllTest {
    class DataCardAllOfScreeningsSectionHasMaternalAntibodyInWeek25IfRhesusNegative {
        @Test
        fun NegativeRhesusType() {
            val allNegative = DataCardAllOfScreeningsSectionEmpty.copy(
                maternalRhD = MaternalRhDScreeningSectionEmpty.copy(
                    rhesusType = PosNegEnum.Negative,
                ),
                maternalAntibody = MaternalAntibodyScreeningSectionEmpty.copy(
                    irregularBloodGroupAntibodyPresent = PosNegEnum.Negative,
                ),
            )
            allNegative.hasMaternalAntibodyInWeek25IfRhesusNegative()
                .assertEquals(PosNegEnum.Negative)

            val negativeRhesusButPositiveAntibody = allNegative.copy(
                maternalAntibody = MaternalAntibodyScreeningSectionEmpty.copy(
                    irregularBloodGroupAntibodyPresent = PosNegEnum.Positive,
                ),
            )
            negativeRhesusButPositiveAntibody.hasMaternalAntibodyInWeek25IfRhesusNegative()
                .assertEquals(PosNegEnum.Positive)

            val nullAntibody = allNegative.copy(maternalAntibody = null)
            nullAntibody.hasMaternalAntibodyInWeek25IfRhesusNegative().assertNull()
        }

        @Test
        fun PositiveRhesusType() {
            DataCardAllOfScreeningsSectionEmpty.copy(
                maternalRhD = MaternalRhDScreeningSectionEmpty.copy(
                    rhesusType = PosNegEnum.Positive,
                ),
                maternalAntibody = MaternalAntibodyScreeningSectionEmpty.copy(
                    irregularBloodGroupAntibodyPresent = PosNegEnum.Negative,
                ),
            ).hasMaternalAntibodyInWeek25IfRhesusNegative().assertNull()
        }

        @Test
        fun nulls() {
            val nullable: DataCardAllOfScreeningsSection? = null
            nullable.hasMaternalAntibodyInWeek25IfRhesusNegative().assertNull()

            DataCardAllOfScreeningsSectionEmpty.copy(
                maternalRhD = MaternalRhDScreeningSectionEmpty.copy(
                    rhesusType = null,
                ),
                maternalAntibody = MaternalAntibodyScreeningSectionEmpty.copy(
                    irregularBloodGroupAntibodyPresent = PosNegEnum.Negative,
                ),
            ).hasMaternalAntibodyInWeek25IfRhesusNegative().assertNull()

            DataCardAllOfScreeningsSectionEmpty.copy(
                maternalRhD = null,
                maternalAntibody = MaternalAntibodyScreeningSectionEmpty.copy(
                    irregularBloodGroupAntibodyPresent = PosNegEnum.Negative,
                ),
            ).hasMaternalAntibodyInWeek25IfRhesusNegative().assertNull()
        }
    }

    class DataCardAllOfScreeningsSectionGetStreptococcusValue {
        @Test
        fun PositiveGroupBResult() {
            val withAllData = DataCardAllOfScreeningsSectionEmpty.copy(
                streptococcusGroupB = PositiveNegativeScreeningWithDateSection(
                    result = PosNegEnum.Positive,
                    date = LocalDateTime.of(2002, 10, 9, 4, 3),
                ),
            )
            withAllData.getStreptococcusValue().assertStringModel("09.10.2002")
        }

        @Test
        fun NegativeResult() {
            val withAllData = DataCardAllOfScreeningsSectionEmpty.copy(
                streptococcusGroupB = PositiveNegativeScreeningWithDateSection(
                    result = PosNegEnum.Negative,
                    date = LocalDateTime.of(2002, 10, 9, 4, 3),
                ),
            )
            withAllData.getStreptococcusValue().assertNull()
        }

        @Test
        fun nulls() {
            val nullable: DataCardAllOfScreeningsSection? = null
            nullable.getStreptococcusValue().assertNull()

            val withoutDate = DataCardAllOfScreeningsSectionEmpty.copy(
                streptococcusGroupB = PositiveNegativeScreeningWithDateSection(
                    result = PosNegEnum.Positive,
                    date = null,
                ),
            )
            withoutDate.getStreptococcusValue().assertNull()

            val withoutResult = DataCardAllOfScreeningsSectionEmpty.copy(
                streptococcusGroupB = PositiveNegativeScreeningWithDateSection(
                    result = null,
                    date = LocalDateTime.of(2002, 10, 9, 4, 3),
                ),
            )
            withoutResult.getStreptococcusValue().assertNull()

            val withoutGroupB = DataCardAllOfScreeningsSectionEmpty.copy(
                streptococcusGroupB = null,
            )
            withoutGroupB.getStreptococcusValue().assertNull()
        }
    }
}
