/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.ui.main.more.MoreSection.Documentation
import dk.nsp.mingraviditet.ui.main.more.MoreSection.Settings
import dk.nsp.mingraviditet.ui.main.more.MoreSection.Support
import dk.nsp.testassertions.assertEquals
import dk.nsp.util.textmodel.TextResourceModel
import org.junit.jupiter.api.Test

class MoreSectionTest {
    @Test
    fun getTitle() {
        (Documentation.getTitle() as TextResourceModel).textRes.assertEquals(R.string.more_documentation_title)
        (Support.getTitle() as TextResourceModel).textRes.assertEquals(R.string.more_support_title)
        (Settings.getTitle() as TextResourceModel).textRes.assertEquals(R.string.more_settings_title)
    }

    @Test
    fun getDescription() {
        (Documentation.getDescription() as TextResourceModel).textRes.assertEquals(R.string.more_documentation_description)
        (Support.getDescription() as TextResourceModel).textRes.assertEquals(R.string.more_support_description)
        (Settings.getDescription() as TextResourceModel).textRes.assertEquals(R.string.more_settings_description)
    }

    @Test
    fun getIcon() {
        Documentation.getIcon().assertEquals(R.drawable.ic_documentation)
        Support.getIcon().assertEquals(R.drawable.ic_support)
        Settings.getIcon().assertEquals(R.drawable.ic_settings)
    }
}
