/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.extensions

import dk.nsp.testassertions.assertEquals
import org.junit.jupiter.api.Test
import java.math.BigDecimal

class BigDecimalExtensionsTest {

    @Test
    fun bigDecimalToTwoDecimalString() {
        BigDecimal(10.144).toTwoDecimalString().assertEquals("10.14")
        BigDecimal(10.175).toTwoDecimalString().assertEquals("10.18")
        BigDecimal(10.166).toTwoDecimalString().assertEquals("10.17")
        BigDecimal(10.004).toTwoDecimalString().assertEquals("10")
    }

    @Test
    fun bigDecimalToString() {
        BigDecimal(10.1632).toString(numberOfDecimals = 3).assertEquals("10.163")
        BigDecimal(10.16).toString(numberOfDecimals = 0).assertEquals("10")

        // Less decimals than target
        BigDecimal(10.16).toString(numberOfDecimals = 3).assertEquals("10.16")

        // Same as target
        BigDecimal(10.16).toString(numberOfDecimals = 2).assertEquals("10.16")

        // Half up
        BigDecimal(10.16).toString(numberOfDecimals = 1).assertEquals("10.2")

        // Trailing Zeros
        BigDecimal(10.004).toString(numberOfDecimals = 2).assertEquals("10")
        BigDecimal(10.025).toString(numberOfDecimals = 2).assertEquals("10.03")
        BigDecimal(10.104).toString(numberOfDecimals = 2).assertEquals("10.1")
    }
}
