/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.extensions

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.testextensions.assertResourceModel
import dk.nsp.models.ObservationType
import dk.nsp.testassertions.assertFalse
import dk.nsp.testassertions.assertTrue
import org.junit.jupiter.api.Test

class ObservationTypeExtensionsTest {

    @Test
    fun observationTypeIsFetusObservation() {
        ObservationType.FetusActivity.isFetusObservation().assertTrue()
        ObservationType.FetusPresentation.isFetusObservation().assertTrue()
        ObservationType.FetusWeightEstimate.isFetusObservation().assertTrue()

        ObservationType.Weight.isFetusObservation().assertFalse()
        ObservationType.BloodPressure.isFetusObservation().assertFalse()
        ObservationType.Urine.isFetusObservation().assertFalse()
        ObservationType.Edema.isFetusObservation().assertFalse()
        ObservationType.PubisMeasurements.isFetusObservation().assertFalse()
        ObservationType.FetusWeightEstimateUltrasound.isFetusObservation().assertFalse()
        ObservationType.FetusPresentationUltrasound.isFetusObservation().assertFalse()
        ObservationType.Cervix.isFetusObservation().assertFalse()
        ObservationType.Dvp.isFetusObservation().assertFalse()
        ObservationType.GestationAge.isFetusObservation().assertFalse()
        ObservationType.GestationAgeUltrasound.isFetusObservation().assertFalse()
        ObservationType.WeightDeviation.isFetusObservation().assertFalse()
        ObservationType.AmnioticFluid.isFetusObservation().assertFalse()
        ObservationType.Flow.isFetusObservation().assertFalse()
    }

    @Test
    fun observationTypeDisplayName() {
        ObservationType.Weight.displayName.assertResourceModel(R.string.journal_section_measurements_table_mothers_weight)
        ObservationType.BloodPressure.displayName.assertResourceModel(R.string.journal_section_measurements_table_blood_pressure)
        ObservationType.Urine.displayName.assertResourceModel(R.string.journal_section_measurements_table_urine_sample)
        ObservationType.Edema.displayName.assertResourceModel(R.string.journal_section_measurements_table_edema)
        ObservationType.PubisMeasurements.displayName.assertResourceModel(R.string.journal_section_measurements_table_pubismeasurement)
        ObservationType.FetusActivity.displayName.assertResourceModel(R.string.journal_section_measurements_table_fetus_activity)
        ObservationType.FetusWeightEstimate.displayName.assertResourceModel(R.string.journal_section_measurements_table_estimated_fetus_weight)
        ObservationType.FetusWeightEstimateUltrasound.displayName.assertResourceModel(R.string.journal_section_scans_table_ultrasound_weight)
        ObservationType.FetusPresentation.displayName.assertResourceModel(R.string.journal_section_scans_table_fetus_presentation)
        ObservationType.FetusPresentationUltrasound.displayName.assertResourceModel(R.string.journal_section_scans_table_fetus_presentation)
        ObservationType.Cervix.displayName.assertResourceModel(R.string.journal_section_scans_table_cervix)
        ObservationType.Dvp.displayName.assertResourceModel(R.string.journal_section_scans_table_dvp)
        ObservationType.GestationAge.displayName.assertResourceModel(R.string.journal_section_scans_table_gestation_age)
        ObservationType.GestationAgeUltrasound.displayName.assertResourceModel(R.string.journal_section_scans_table_gestation_age)
        ObservationType.WeightDeviation.displayName.assertResourceModel(R.string.journal_section_scans_table_weight_deviation)
        ObservationType.AmnioticFluid.displayName.assertResourceModel(R.string.journal_section_scans_table_amniotic_fluid)
        ObservationType.Flow.displayName.assertResourceModel(R.string.journal_section_scans_table_flow)

        val nullable: ObservationType? = null
        nullable.displayName.assertResourceModel(R.string.common_missing_data)
    }
}
