/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.util.extensions

import dk.nsp.mingraviditet.R
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIs
import dk.nsp.testassertions.assertIsAndApply
import dk.nsp.util.textmodel.TextResourceModel
import dk.nsp.util.textmodel.TextStringModel
import org.junit.jupiter.api.Test

class TextModelExtensionsTest {
    @Test
    fun testStringToTextModelOrDefault() {
        val nullString: String? = null
        val nullModel = nullString.toTextModelOrDefault()
        nullModel.assertIs<TextResourceModel>()
        nullModel.textRes.assertEquals(R.string.common_missing_data)

        val emptyString = "".toTextModelOrDefault()
        emptyString.assertIs<TextResourceModel>()
        emptyString.textRes.assertEquals(R.string.common_missing_data)

        val valueString = "value".toTextModelOrDefault()
        valueString.assertIs<TextStringModel>()
        valueString.text.assertEquals("value")
    }

    @Test
    fun booleanToYesNoTextModelOrDefault() {
        val nullBool: Boolean? = null
        val nullModel = nullBool.toYesNoTextModelOrDefault()
        nullModel.assertIs<TextResourceModel>()
        nullModel.textRes.assertEquals(R.string.common_missing_data)

        val noModel = false.toYesNoTextModelOrDefault()
        noModel.assertIs<TextResourceModel>()
        noModel.textRes.assertEquals(R.string.enum_no)

        val yesModel = true.toYesNoTextModelOrDefault()
        yesModel.assertIs<TextResourceModel>()
        yesModel.textRes.assertEquals(R.string.enum_yes)
    }

    @Test
    fun intToTextModelOrDefault() {
        val nullInt: Int? = null
        val nullModel = nullInt.toTextModelOrDefault()
        nullModel.assertIs<TextResourceModel>()
        nullModel.textRes.assertEquals(R.string.common_missing_data)

        val valueModel = 428.toTextModelOrDefault()
        valueModel.assertIs<TextStringModel>()
        valueModel.text.assertEquals("428")
    }

    @Test
    fun intToTextModelOrNull() {
        val valueModel = 428.toTextModel()
        valueModel.assertIsAndApply<TextStringModel> {
            text.assertEquals("428")
        }
    }
}
