/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.articles

import dk.nsp.domain.repository.ArticlesRepository
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.util.asyncDefault
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

data class RecommendedArticleCategory(
    val currentWeek: List<ArticleCategory>,
    val nextWeek: List<ArticleCategory>,
)

sealed class RecommendedArticleCategoryType {
    abstract fun CoroutineScope.getRecommendedArticles(
        repository: ArticlesRepository,
        week: Int,
    ): Deferred<ResultWrapper<RecommendedArticleCategory>>

    object InBirth : RecommendedArticleCategoryType() {
        override fun CoroutineScope.getRecommendedArticles(
            repository: ArticlesRepository,
            week: Int,
        ): Deferred<ResultWrapper<RecommendedArticleCategory>> = asyncDefault {
            with(repository) { getArticleCategories(week) }.await()
        }
    }

    object AfterBirth : RecommendedArticleCategoryType() {
        override fun CoroutineScope.getRecommendedArticles(
            repository: ArticlesRepository,
            week: Int,
        ): Deferred<ResultWrapper<RecommendedArticleCategory>> = asyncDefault {
            with(repository) { getAfterBirthArcticleCategories(week) }.await()
        }
    }
}
