/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.auth

import dk.nsp.api.util.isHttpErrorWithCode
import dk.nsp.api.util.networkErrorsApi
import dk.nsp.domain.bll.isRefreshTokenExpired
import dk.nsp.domain.bll.networkErrors

@JvmInline
value class ThrowableLoginErrors(val throwable: Throwable)

inline val Throwable.loginErrors: ThrowableLoginErrors
    get() = ThrowableLoginErrors(this)

fun ThrowableLoginErrors.isHttpErrorWithCode(code: Int): Boolean {
    return throwable.networkErrorsApi.isHttpErrorWithCode(code)
}

/**
 * User has entered a bad pin
 * @receiver ThrowableNetworkErrors
 * @return Boolean
 */
fun ThrowableLoginErrors.isBadPin(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(401)
}

/**
 * Key is locked serverside, requires relogin
 * @receiver ThrowableNetworkErrors
 */
fun ThrowableLoginErrors.isKeyLocked(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(403)
}

/**
 * Key couldn't be found
 * @receiver ThrowableNetworkErrors
 */
fun ThrowableLoginErrors.keyNotFound(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(404)
}

fun ThrowableLoginErrors.couldNotCreateKey(): Boolean {
    return throwable.loginErrors.isHttpErrorWithCode(500)
}
fun ThrowableLoginErrors.isRefreshTokenExpired(): Boolean {
    return throwable.networkErrors.isRefreshTokenExpired()
}
