/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.repository

import android.content.Context
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import dk.nsp.api.getBackendApiLayer
import dk.nsp.models.Activity
import dk.nsp.models.CarePlan
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.asSuccessValueOrNull
import dk.nsp.shared.util.asyncDefault
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

class CareplanRepository(context: Context) : ClearableRepository {
    private val careplanController = context.getBackendApiLayer().careplanController

    private val _selectedCareplan: MutableLiveData<ResultWrapper<CarePlan>?> = MutableLiveData()
    val selectedCareplan: LiveData<ResultWrapper<CarePlan>?> = _selectedCareplan

    fun getCareplans(
        scope: CoroutineScope,
        episodeOfCareId: String,
    ): Deferred<ResultWrapper<CarePlan>> =
        scope.asyncDefault {
            val careplansRes = careplanController.getCareplan(this, episodeOfCareId).await()

            _selectedCareplan.postValue(careplansRes)
            return@asyncDefault careplansRes
        }

    fun getCareplanActivity(activityId: String): Activity? {
        return _selectedCareplan.value
            ?.asSuccessValueOrNull()
            ?.activities
            ?.find {
                it.id == activityId
            }
    }

    override fun clear() {
        _selectedCareplan.postValue(null)
    }
}
