/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.repository

import android.content.Context
import dk.nsp.api.getBackendApiLayer
import dk.nsp.models.ObservationTable
import dk.nsp.models.ScanningObservationTable
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.util.asyncDefault
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

class ObservationsRepository(context: Context) {
    private val observationsController = context.getBackendApiLayer().observationsController

    fun getClinicalObservationsAsync(
        scope: CoroutineScope,
        episodeOfCareIdentifier: String,
    ): Deferred<ResultWrapper<ObservationTable>> =
        scope.asyncDefault {
            observationsController.getClinicalObservationsTable(scope, episodeOfCareIdentifier)
                .await()
        }

    fun getScanObservationsTable(scope: CoroutineScope, episodeOfCareIdentifier: String): Deferred<ResultWrapper<ScanningObservationTable>> = scope.asyncDefault {
        observationsController.getScanObservationsTable(scope, episodeOfCareIdentifier).await()
    }
}
