/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.util

import android.text.Html
import dk.nsp.domain.articles.ArticleCategory
import dk.nsp.models.ArticleSearchResult

fun ArticleCategory.searchResults(): List<ArticleSearchResult> {
    val results = mutableListOf<ArticleSearchResult>()

    articles.forEach { article ->

        article.searchOrder?.let { searchOrder ->
            results.add(
                ArticleSearchResult(
                    title = article.title,
                    description = article.description,
                    subtitle = name,
                    iconUrl = icon,
                    article = article,
                    searchOrder = searchOrder,
                    articleSectionId = null,
                ),
            )
        }

        val sections = article.sections.mapNotNull { section ->
            section.searchOrder?.let { searchOrder ->
                ArticleSearchResult(
                    title = section.title,
                    description = Html.fromHtml(section.content, Html.FROM_HTML_MODE_LEGACY).toString(),
                    subtitle = "$name • ${article.title}",
                    iconUrl = icon,
                    article = article,
                    searchOrder = searchOrder,
                    articleSectionId = section.id,
                )
            }
        }
        results.addAll(sections)
    }

    return results.sortedBy { it.searchOrder }
}

fun List<ArticleCategory>.hasSearchResults(): Boolean {
    return any { it.searchResults().isNotEmpty() }
}
