/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.util.textmodel

import android.content.res.Resources
import kotlinx.parcelize.Parcelize

/**
 * A type of [TextModel] used for combining multiple [TextModel]s with a separator
 */
@Parcelize
class TextCompositeModel(
    val bindings: List<TextModel>,
    val seperator: TextModel? = null,
) : TextModel() {
    override fun getString(resources: Resources): String {
        val separatorString = seperator?.getString(resources) ?: ""
        return bindings.joinToString(separator = separatorString) { it.getString(resources) ?: "" }
    }

    override fun hashCode(): Int {
        var result = super.hashCode()
        result = 31 * result + seperator.hashCode()
        result = 31 * result + bindings.hashCode()
        return result
    }

    override fun equals(other: Any?): Boolean =
        other is TextCompositeModel &&
            seperator == other.seperator &&
            bindings.toTypedArray().contentDeepEquals(other.bindings.toTypedArray())
}
