/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.knowledge

import dk.nsp.api.cms.models.ArticleContentSectionDTO
import dk.nsp.api.cms.models.ArticleDTO
import dk.nsp.domain.articles.toDomainModel
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertNotNullAndEquals
import org.junit.jupiter.api.Test
import java.time.LocalDateTime

class ArticlesTest {

    private val basicContentSection = ArticleContentSectionDTO(
        id = 10,
        title = "Title",
        searchOrder = 1,
        content = "Content",
        weeks = listOf("Uge 3", "Uge 4"),
    )

    private val basicArticle = ArticleDTO(
        id = 1,
        title = "Title",
        searchOrder = 1,
        lastUpdated = LocalDateTime.of(2020, 10, 14, 12, 52),
        description = "Description",
        content = "Content",
        sections = listOf(
            basicContentSection.copy(10),
            basicContentSection.copy(11),
            basicContentSection.copy(12),
        ),
    )

    @Test
    fun articleDTOToDomainModel() {
        val source = basicArticle
        val result = source.toDomainModel()

        result.id.assertEquals(basicArticle.id)
        result.title.assertEquals(basicArticle.title)
        result.searchOrder.assertEquals(basicArticle.searchOrder)
        result.lastUpdated.assertEquals(basicArticle.lastUpdated)
        result.description.assertEquals(basicArticle.description)
        result.sections.let {
            it.size.assertEquals(3)

            it.getOrNull(0)?.id?.assertNotNullAndEquals(10)
            it.getOrNull(1)?.id?.assertNotNullAndEquals(11)
            it.getOrNull(2)?.id?.assertNotNullAndEquals(12)
        }
    }

    @Test
    fun articleContentSectionDTOToDomainModel() {
        val source = basicContentSection
        val result = basicContentSection.toDomainModel()

        result.id.assertEquals(source.id)
        result.content.assertEquals(source.content)
        result.searchOrder.assertEquals(source.searchOrder)
        result.title.assertEquals(source.title)
        result.weeks.assertEquals(source.weeks)
    }

    @Test
    fun listArticeContentSectionDTOToDomainModel() {
        val result = listOf(
            basicContentSection.copy(id = 10),
            basicContentSection.copy(id = 11),
            basicContentSection.copy(id = 12),
        )

        result.size.assertEquals(3)

        result.getOrNull(0)?.id?.assertNotNullAndEquals(10)
        result.getOrNull(1)?.id?.assertNotNullAndEquals(11)
        result.getOrNull(2)?.id?.assertNotNullAndEquals(12)
    }
}
