/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.repository

import android.content.Context
import dk.nsp.api.IBackendApiLayer
import dk.nsp.api.cms.ICMSController
import dk.nsp.api.cms.models.PageDTO
import dk.nsp.domain.SettingSubSectionUrl
import dk.nsp.domain.pages.Page
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import dk.nsp.shared.toSuccess
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIs
import dk.nsp.testassertions.assertIsAndApply
import io.mockk.coEvery
import io.mockk.every
import io.mockk.mockk
import io.mockk.mockkObject
import kotlinx.coroutines.runBlocking
import org.junit.jupiter.api.Test

class SettingsPagesRepositoryTest {

    val mockedController = mockk<ICMSController> {
        coEvery {
            getPageContent(
                any(),
                SettingSubSectionUrl.AboutTheApp.path,
            ).await()
        } returns Failed(Exception("Could not get info about the app"))

        coEvery {
            getPageContent(
                any(),
                SettingSubSectionUrl.Consent.path,
            ).await()
        } returns PageDTO(
            "content test",
        ).toSuccess()
    }

    val mockBackend = mockk<IBackendApiLayer> {
        every {
            cmsController
        } returns mockedController
    }

    private fun getRepo(): SettingsPagesRepository {
        mockkObject(IBackendApiLayer)
        every {
            IBackendApiLayer.getLayer(any())
        } returns mockBackend

        val mockedContext = mockk<Context>(relaxed = true)

        return SettingsPagesRepository(mockedContext)
    }

    @Test
    fun getPage() = runBlocking {
        val repo = getRepo()

        repo.getPage(this, SettingSubSectionUrl.AboutTheApp)
            .await()
            .assertIs<Failed>()

        repo.getPage(this, SettingSubSectionUrl.Consent)
            .await()
            .assertIsAndApply<Success<Page>> {
                value.content.assertEquals("content test")
            }
    }
}
