/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.util.textmodel

import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIsAndApply
import dk.nsp.testassertions.assertNotNullAndApply
import dk.nsp.testassertions.assertNull
import org.junit.jupiter.api.Test

class TextModelTest {

    class CompanionTest {

        @Test
        fun fromStringRes() {
            TextModel.from(0).assertEquals(TextResourceModel(0))
        }

        @Test
        fun fromStringResWithPlaceholders() {
            TextModel.from(20, TextStringModel("Model1"), TextResourceModel(10))
                .assertIsAndApply<TextResourcePlaceholderModel> {
                    textRes.assertEquals(20)
                    placeholders.size.assertEquals(2)
                    placeholders.getOrNull(0).assertIsAndApply<TextStringModel> {
                        text.assertEquals("Model1")
                    }
                    placeholders.getOrNull(1).assertIsAndApply<TextResourceModel> {
                        textRes.assertEquals(10)
                    }
                }
        }

        @Test
        fun fromString() {
            TextModel.from("Test").assertIsAndApply<TextStringModel> {
                text.assertEquals("Test")
            }
        }

        @Test
        fun fromResourceQuantityModel() {
            TextModel.from(
                pluralStringRes = 0,
                quantity = 10,
                TextResourceModel(17),
                TextStringModel("16"),
            ).assertIsAndApply<TextResourceQuantityModel> {
                pluralStringRes
                quantity.assertEquals(10)
                placeholderValues.assertNotNullAndApply {
                    size.assertEquals(2)

                    getOrNull(0).assertIsAndApply<TextResourceModel> {
                        textRes.assertEquals(17)
                    }
                    getOrNull(1).assertIsAndApply<TextStringModel> {
                        text.assertEquals("16")
                    }
                }
            }

            TextModel.from(
                pluralStringRes = 15,
                quantity = 19,
            ).assertIsAndApply<TextResourceQuantityModel> {
                placeholderValues.assertNull()
            }
        }

        @Test
        fun fromModelsWithSeperator() {
            TextModel.from(
                listOf(
                    TextStringModel("First item"),
                    TextResourceModel(100),
                ),
                seperator = TextStringModel(", "),
            ).assertIsAndApply<TextCompositeModel> {
                seperator.assertIsAndApply<TextStringModel> {
                    text.assertEquals(", ")
                }
                bindings.size.assertEquals(2)

                bindings.getOrNull(0).assertIsAndApply<TextStringModel> {
                    text.assertEquals("First item")
                }

                bindings.getOrNull(1).assertIsAndApply<TextResourceModel> {
                    textRes.assertEquals(100)
                }
            }

            TextModel.from(
                listOf(
                    TextStringModel("SingleItem"),
                ),
                seperator = null,
            ).assertIsAndApply<TextCompositeModel> {
                seperator.assertNull()
            }
        }
    }
}
