/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 *
 *
 * @param patient
 * @param title
 * @param responsibleOrganization
 * @param activities
 * @param processId A reference to any external clinical pathway that this care plan is a part of
 * @param description
 * @param id
 * @param version
 * @param documentStatus
 */
@Parcelize
data class CarePlan(

    @Json(name = "patient")
    val patient: kotlin.String,

    @Json(name = "title")
    val title: kotlin.String,

    @Json(name = "responsibleOrganization")
    val responsibleOrganization: CarePlanResponsibleOrganization,

    @Json(name = "activities")
    val activities: kotlin.collections.List<Activity>? = null,

    // A reference to any external clinical pathway that this care plan is a part of
    @Json(name = "processId")
    val processId: kotlin.String? = null,

    @Json(name = "description")
    val description: kotlin.String? = null,

    @Json(name = "id")
    val id: kotlin.String? = null,

    @Json(name = "version")
    val version: java.math.BigDecimal? = null,

    @Json(name = "documentStatus")
    val documentStatus: CarePlan.DocumentStatus? = null,

) : Parcelable {

    /**
     *
     *
     * Values: NEW,ACTIVE,CLOSED,PARTIAL
     */
    enum class DocumentStatus(val value: kotlin.String) {
        @Json(name = "NEW")
        NEW("NEW"),

        @Json(name = "ACTIVE")
        ACTIVE("ACTIVE"),

        @Json(name = "CLOSED")
        CLOSED("CLOSED"),

        @Json(name = "PARTIAL")
        PARTIAL("PARTIAL"),
    }
}
