/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 *
 *
 * @param modifiedTime
 * @param author
 * @param dirty
 * @param conditions
 * @param comment
 */
@Parcelize
data class ChronicDiseasesSection(

    @Json(name = "modifiedTime")
    val modifiedTime: java.time.LocalDateTime? = null,

    @Json(name = "author")
    val author: HealthCareOrganization? = null,

    @Json(name = "dirty")
    val dirty: kotlin.Boolean? = null,

    @Json(name = "conditions")
    val conditions: kotlin.collections.List<ChronicDiseasesSection.Conditions>? = null,

    @Json(name = "comment")
    val comment: kotlin.String? = null,

) : Parcelable {

    /**
     *
     *
     * Values: CirculatorySystem,RespiratorySystem,Thyroid,Diabetes,Epilepsy,MentalIllness,Herpes,Uvi,ConeSection,Mrsa,Gbs
     */
    enum class Conditions(val value: kotlin.String) {
        @Json(name = "circulatory_system")
        CirculatorySystem("circulatory_system"),

        @Json(name = "respiratory_system")
        RespiratorySystem("respiratory_system"),

        @Json(name = "thyroid")
        Thyroid("thyroid"),

        @Json(name = "diabetes")
        Diabetes("diabetes"),

        @Json(name = "epilepsy")
        Epilepsy("epilepsy"),

        @Json(name = "mental_illness")
        MentalIllness("mental_illness"),

        @Json(name = "herpes")
        Herpes("herpes"),

        @Json(name = "uvi")
        Uvi("uvi"),

        @Json(name = "cone_section")
        ConeSection("cone_section"),

        @Json(name = "mrsa")
        Mrsa("mrsa"),

        @Json(name = "gbs")
        Gbs("gbs"),
    }
}
