/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 *
 *
 * @param episodeOfCareIdentifier
 * @param recordTarget
 * @param modifiedTime
 * @param author
 * @param dirty
 * @param documentUniqueId
 * @param version
 * @param documentStatus
 * @param closeDateTime
 * @param childPartnerSection
 * @param languageSection
 * @param bodyMeasuresSection
 * @param socialHistorySection
 * @param previousBirthsSection
 * @param previousAbortionsSection
 * @param expectedDateOfDeliverySection
 * @param ultrasoundSection
 * @param prenatalRiskAssessmentSection
 * @param workEnvironmentImpactSection
 * @param allergiesSection
 * @param screeningsSection
 * @param chronicDiseasesSection
 * @param medicineSection
 * @param mmrVaccinationSection
 * @param historyOfPreviousTreatmentWithImpactOnPregnancySection
 * @param tobaccoUseAndExposureSection
 * @param alcoholDrinkingBehaviorSection
 * @param assistedFertilizationSection
 * @param substanceUseSection
 * @param dietaryAndExerciseSection
 * @param healthInsuranceSection
 * @param desiredBirthPlaceSection
 * @param primaryPlannedBirthPlaceSection
 * @param revisedPlannedBirthPlaceSection
 * @param midwifeClinicSection
 * @param midwifeConsultationSection
 * @param overallAssessmentSection
 * @param multiplePregnancySection
 * @param personalDataSection
 * @param healthcareSection
 */
@Parcelize
data class DataCard(

    @Json(name = "episodeOfCareIdentifier")
    val episodeOfCareIdentifier: kotlin.String,

    @Json(name = "recordTarget")
    val recordTarget: CprIdentifiedPerson,

    @Json(name = "modifiedTime")
    val modifiedTime: java.time.LocalDateTime? = null,

    @Json(name = "author")
    val author: HealthCareOrganization? = null,

    @Json(name = "dirty")
    val dirty: kotlin.Boolean? = null,

    @Json(name = "documentUniqueId")
    val documentUniqueId: kotlin.String? = null,

    @Json(name = "version")
    val version: kotlin.String? = null,

    @Json(name = "documentStatus")
    val documentStatus: DataCard.DocumentStatus? = null,

    @Json(name = "closeDateTime")
    val closeDateTime: java.time.LocalDateTime? = null,

    @Json(name = "childPartnerSection")
    val childPartnerSection: ChildPartnerSection? = null,

    @Json(name = "languageSection")
    val languageSection: LanguageSection? = null,

    @Json(name = "bodyMeasuresSection")
    val bodyMeasuresSection: BodyMeasuresSection? = null,

    @Json(name = "socialHistorySection")
    val socialHistorySection: SocialHistorySection? = null,

    @Json(name = "previousBirthsSection")
    val previousBirthsSection: PreviousBirthsSection? = null,

    @Json(name = "previousAbortionsSection")
    val previousAbortionsSection: PreviousAbortionsSection? = null,

    @Json(name = "expectedDateOfDeliverySection")
    val expectedDateOfDeliverySection: ExpectedDateOfDeliverySection? = null,

    @Json(name = "ultrasoundSection")
    val ultrasoundSection: UltrasoundSection? = null,

    @Json(name = "prenatalRiskAssessmentSection")
    val prenatalRiskAssessmentSection: PrenatalRiskAssessmentSection? = null,

    @Json(name = "workEnvironmentImpactSection")
    val workEnvironmentImpactSection: WorkEnvironmentImpactSection? = null,

    @Json(name = "allergiesSection")
    val allergiesSection: AllergiesSection? = null,

    @Json(name = "screeningsSection")
    val screeningsSection: DataCardAllOfScreeningsSection? = null,

    @Json(name = "chronicDiseasesSection")
    val chronicDiseasesSection: ChronicDiseasesSection? = null,

    @Json(name = "medicineSection")
    val medicineSection: MedicineSection? = null,

    @Json(name = "mmrVaccinationSection")
    val mmrVaccinationSection: MmrVaccinationSection? = null,

    @Json(name = "historyOfPreviousTreatmentWithImpactOnPregnancySection")
    val historyOfPreviousTreatmentWithImpactOnPregnancySection: HistoryOfPreviousTreatmentWithImpactOnPregnancySection? = null,

    @Json(name = "tobaccoUseAndExposureSection")
    val tobaccoUseAndExposureSection: TobaccoUseAndExposureSection? = null,

    @Json(name = "alcoholDrinkingBehaviorSection")
    val alcoholDrinkingBehaviorSection: AlcoholDrinkingBehaviorSection? = null,

    @Json(name = "assistedFertilizationSection")
    val assistedFertilizationSection: AssistedFertilizationSection? = null,

    @Json(name = "substanceUseSection")
    val substanceUseSection: SubstanceUseSection? = null,

    @Json(name = "dietaryAndExerciseSection")
    val dietaryAndExerciseSection: DietaryAndExerciseSection? = null,

    @Json(name = "healthInsuranceSection")
    val healthInsuranceSection: HealthInsuranceSection? = null,

    @Json(name = "desiredBirthPlaceSection")
    val desiredBirthPlaceSection: DesiredBirthPlaceSection? = null,

    @Json(name = "primaryPlannedBirthPlaceSection")
    val primaryPlannedBirthPlaceSection: PrimaryPlannedBirthPlaceSection? = null,

    @Json(name = "revisedPlannedBirthPlaceSection")
    val revisedPlannedBirthPlaceSection: RevisedPlannedBirthPlaceSection? = null,

    @Json(name = "midwifeClinicSection")
    val midwifeClinicSection: MidwifeClinicSection? = null,

    @Json(name = "midwifeConsultationSection")
    val midwifeConsultationSection: MidwifeConsultationSection? = null,

    @Json(name = "overallAssessmentSection")
    val overallAssessmentSection: OverallAssessmentSection? = null,

    @Json(name = "multiplePregnancySection")
    val multiplePregnancySection: MultiplePregnancySection? = null,

    @Json(name = "personalDataSection")
    val personalDataSection: PersonalDataSection? = null,

    @Json(name = "healthcareSection")
    val healthcareSection: HealthCareSection? = null,

) : Parcelable {

    /**
     *
     *
     * Values: NEW,ACTIVE,CLOSED,PARTIAL
     */
    enum class DocumentStatus(val value: kotlin.String) {
        @Json(name = "NEW")
        NEW("NEW"),

        @Json(name = "ACTIVE")
        ACTIVE("ACTIVE"),

        @Json(name = "CLOSED")
        CLOSED("CLOSED"),

        @Json(name = "PARTIAL")
        PARTIAL("PARTIAL"),
    }
}
