/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 *
 *
 * @param hepatitisB
 * @param hiv
 * @param syphilis
 * @param chlamydia
 * @param gonorrhea
 * @param streptococcusGroupB
 * @param hemoglobinopathy
 * @param vitaminDConsumption
 * @param maternalRhD
 * @param maternalAntibody
 * @param maternalBloodtype
 * @param fetalRhDAntibody
 * @param diabetesWeek18To20
 * @param diabetesWeek28To30
 * @param diabetesGlycosuria
 * @param antiDImmunoglobulinGiven
 * @param mrsaSwap
 */
@Parcelize
data class DataCardAllOfScreeningsSection(

    @Json(name = "hepatitisB")
    val hepatitisB: PositiveNegativeDeclinedScreeningWithDateSection? = null,

    @Json(name = "hiv")
    val hiv: PositiveNegativeDeclinedScreeningWithDateSection? = null,

    @Json(name = "syphilis")
    val syphilis: PositiveNegativeDeclinedScreeningWithDateSection? = null,

    @Json(name = "chlamydia")
    val chlamydia: PositiveNegativeScreeningWithDateSection? = null,

    @Json(name = "gonorrhea")
    val gonorrhea: PositiveNegativeScreeningWithDateSection? = null,

    @Json(name = "streptococcusGroupB")
    val streptococcusGroupB: PositiveNegativeScreeningWithDateSection? = null,

    @Json(name = "hemoglobinopathy")
    val hemoglobinopathy: PositiveNegativeScreeningWithDateSection? = null,

    @Json(name = "vitaminDConsumption")
    val vitaminDConsumption: DateValueUnitScreeningSection? = null,

    @Json(name = "maternalRhD")
    val maternalRhD: MaternalRhDScreeningSection? = null,

    @Json(name = "maternalAntibody")
    val maternalAntibody: MaternalAntibodyScreeningSection? = null,

    @Json(name = "maternalBloodtype")
    val maternalBloodtype: MaternalBloodtypeScreeningSection? = null,

    @Json(name = "fetalRhDAntibody")
    val fetalRhDAntibody: FetalRhDAntibodyScreeningSection? = null,

    @Json(name = "diabetesWeek18To20")
    val diabetesWeek18To20: DateValueUnitScreeningSection? = null,

    @Json(name = "diabetesWeek28To30")
    val diabetesWeek28To30: DateValueUnitScreeningSection? = null,

    @Json(name = "diabetesGlycosuria")
    val diabetesGlycosuria: DateValueUnitScreeningSection? = null,

    @Json(name = "antiDImmunoglobulinGiven")
    val antiDImmunoglobulinGiven: YesNoDateScreeningSection? = null,

    @Json(name = "mrsaSwap")
    val mrsaSwap: YesNoDateScreeningSection? = null,

) : Parcelable
