/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 *
 *
 * @param expectedDateOfDeliveryFromLastPeriod
 * @param offsetDate Computed conception date. Computed either from ultrasound gestation age or from last period.
 * @param dateOfDelivery Computed date of delivery. Computed either from ultrasound gestation age or from last period.
 * @param gestationAge Computed gestation age formatted as 'Weeks+Days'. Computed from 273 days minus days to expectedDateOfDeliveryFromPrenatalUltrasoundScan if present. Otherwise computed from expectedDateOfDeliveryFromLastPeriod.
 * @param trimester Computed trimester (i.e. monthsIntoPregnancy/3).
 * @param monthsIntoPregnancy Computed number of months into pregnanancy. Computed from expectedDateOfDeliveryFromPrenatalUtrasoundScan if presenent and expectedDateOfDeliveryFromLastPeriod otherwise. If both are null this wil be 0
 * @param week Computed Gestation Week. Computed from gestationAge. '17+6' = 18 and '18+0' = 19
 * @param remarks
 */
@Parcelize
data class ExpectedDateOfDeliverySectionAllOf(

    @Json(name = "expectedDateOfDeliveryFromLastPeriod")
    val expectedDateOfDeliveryFromLastPeriod: ExpectedDateOfDeliverySectionAllOfExpectedDateOfDeliveryFromLastPeriod? = null,

    // Computed conception date. Computed either from ultrasound gestation age or from last period.
    @Json(name = "offsetDate")
    val offsetDate: java.time.LocalDateTime? = null,

    // Computed date of delivery. Computed either from ultrasound gestation age or from last period.
    @Json(name = "dateOfDelivery")
    val dateOfDelivery: java.time.LocalDateTime? = null,

    // Computed gestation age formatted as 'Weeks+Days'. Computed from 273 days minus days to expectedDateOfDeliveryFromPrenatalUltrasoundScan if present. Otherwise computed from expectedDateOfDeliveryFromLastPeriod.
    @Json(name = "gestationAge")
    val gestationAge: kotlin.String? = null,

    // Computed trimester (i.e. monthsIntoPregnancy/3).
    @Json(name = "trimester")
    val trimester: kotlin.Int? = null,

    // Computed number of months into pregnanancy. Computed from expectedDateOfDeliveryFromPrenatalUtrasoundScan if presenent and expectedDateOfDeliveryFromLastPeriod otherwise. If both are null this wil be 0
    @Json(name = "monthsIntoPregnancy")
    val monthsIntoPregnancy: kotlin.Double? = null,

    // Computed Gestation Week. Computed from gestationAge. '17+6' = 18 and '18+0' = 19
    @Json(name = "week")
    val week: kotlin.Int? = null,

    @Json(name = "remarks")
    val remarks: kotlin.String? = null,

) : Parcelable
