/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 * represents a note
 *
 * @param content
 * @param title
 * @param date The time the note were observed
 * @param createdDate The time the note were created
 * @param careplanId A unique pointer to the careplan document from which this appointment origins
 * @param enteredby
 * @param documentUniqueId
 * @param dirty
 */
@Parcelize
data class Note(

    @Json(name = "content")
    val content: kotlin.String,

    @Json(name = "title")
    val title: kotlin.String? = null,

    // The time the note were observed
    @Json(name = "date")
    val date: java.time.LocalDateTime? = null,

    // The time the note were created
    @Json(name = "createdDate")
    val createdDate: java.time.LocalDateTime? = null,

    // A unique pointer to the careplan document from which this appointment origins
    @Json(name = "careplanId")
    val careplanId: kotlin.String? = null,

    @Json(name = "enteredby")
    val enteredby: HealthCarePerformer? = null,

    @Json(name = "documentUniqueId")
    val documentUniqueId: kotlin.String? = null,

    @Json(name = "dirty")
    val dirty: kotlin.Boolean? = null,

) : Parcelable
