/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import com.squareup.moshi.Json

/**
 *
 *
 * Values: Weight,BloodPressure,Urine,Edema,PubisMeasurements,FetusActivity,FetusWeightEstimate,FetusWeightEstimateUltrasound,FetusPresentation,FetusPresentationUltrasound,Cervix,Dvp,GestationAge,GestationAgeUltrasound,WeightDeviation,AmnioticFluid,Flow
 */

enum class ObservationType(val value: kotlin.String) {

    @Json(name = "weight")
    Weight("weight"),

    @Json(name = "blood_pressure")
    BloodPressure("blood_pressure"),

    @Json(name = "urine")
    Urine("urine"),

    @Json(name = "edema")
    Edema("edema"),

    @Json(name = "pubis_measurements")
    PubisMeasurements("pubis_measurements"),

    @Json(name = "fetus_activity")
    FetusActivity("fetus_activity"),

    @Json(name = "fetus_weight_estimate")
    FetusWeightEstimate("fetus_weight_estimate"),

    @Json(name = "fetus_weight_estimate_ultrasound")
    FetusWeightEstimateUltrasound("fetus_weight_estimate_ultrasound"),

    @Json(name = "fetus_presentation")
    FetusPresentation("fetus_presentation"),

    @Json(name = "fetus_presentation_ultrasound")
    FetusPresentationUltrasound("fetus_presentation_ultrasound"),

    @Json(name = "cervix")
    Cervix("cervix"),

    @Json(name = "dvp")
    Dvp("dvp"),

    @Json(name = "gestation_age")
    GestationAge("gestation_age"),

    @Json(name = "gestation_age_ultrasound")
    GestationAgeUltrasound("gestation_age_ultrasound"),

    @Json(name = "weight_deviation")
    WeightDeviation("weight_deviation"),

    @Json(name = "amniotic_fluid")
    AmnioticFluid("amniotic_fluid"),

    @Json(name = "flow")
    Flow("flow"),
    ;

    /**
     * Override toString() to avoid using the enum variable name as the value, and instead use
     * the actual value defined in the API spec file.
     *
     * This solves a problem when the variable name and its value are different, and ensures that
     * the client sends the correct enum values to the server always.
     */
    override fun toString(): String = value

    companion object {
        /**
         * Converts the provided [data] to a [String] on success, null otherwise.
         */
        fun encode(data: kotlin.Any?): kotlin.String? = if (data is ObservationType) "$data" else null

        /**
         * Returns a valid [ObservationType] for [data], null otherwise.
         */
        fun decode(data: kotlin.Any?): ObservationType? = data?.let {
            val normalizedData = "$it".lowercase()
            values().firstOrNull { value ->
                it == value || normalizedData == "$value".lowercase()
            }
        }
    }
}
