/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 *
 *
 * @param name
 * @param relation
 * @param telecoms
 * @param additionalInformation
 */
@Parcelize
data class PersonalDataSectionNextOfKin(

    @Json(name = "name")
    val name: PersonName? = null,

    @Json(name = "relation")
    val relation: PersonalDataSectionNextOfKin.Relation? = null,

    @Json(name = "telecoms")
    val telecoms: Telecoms? = null,

    @Json(name = "additionalInformation")
    val additionalInformation: kotlin.String? = null,

) : Parcelable {

    /**
     *
     *
     * Values: UspecPRRende,IngenRelationer,Barn,Mor,Far,ForLder,SSkende,GtefLle,Barnebarn,Svigerbarn,VrigFamilie,Nabo,Samboende,RegistreretPartner,Anden,SN,Datter
     */
    enum class Relation(val value: kotlin.String) {
        @Json(name = "uspec_pårørende")
        UspecPRRende("uspec_pårørende"),

        @Json(name = "ingen_relationer")
        IngenRelationer("ingen_relationer"),

        @Json(name = "barn")
        Barn("barn"),

        @Json(name = "mor")
        Mor("mor"),

        @Json(name = "far")
        Far("far"),

        @Json(name = "forælder")
        ForLder("forælder"),

        @Json(name = "søskende")
        SSkende("søskende"),

        @Json(name = "ægtefælle")
        GtefLle("ægtefælle"),

        @Json(name = "barnebarn")
        Barnebarn("barnebarn"),

        @Json(name = "svigerbarn")
        Svigerbarn("svigerbarn"),

        @Json(name = "øvrig_familie")
        VrigFamilie("øvrig_familie"),

        @Json(name = "nabo")
        Nabo("nabo"),

        @Json(name = "samboende")
        Samboende("samboende"),

        @Json(name = "registreret_partner")
        RegistreretPartner("registreret_partner"),

        @Json(name = "anden")
        Anden("anden"),

        @Json(name = "søn")
        SN("søn"),

        @Json(name = "datter")
        Datter("datter"),
    }
}
