/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 *
 *
 * @param children
 * @param year
 * @param gestationLength
 * @param gestationLengthWeeks
 * @param gestationLengthString
 * @param birthPlace
 * @param pregnancySummary
 * @param birthSummary
 * @param subjectiveBirthExperience
 * @param puerperalSepsis
 */
@Parcelize
data class PreviousBirthsSectionAllOfBirths(

    @Json(name = "children")
    val children: kotlin.collections.List<PreviousBirthsSectionAllOfChildren>? = null,

    @Json(name = "year")
    val year: kotlin.Int? = null,

    @Json(name = "gestationLength")
    val gestationLength: IntegerValueWithUnitEnum? = null,

    @Json(name = "gestationLengthWeeks")
    val gestationLengthWeeks: IntegerValueWithUnitEnum? = null,

    @Json(name = "gestationLengthString")
    val gestationLengthString: kotlin.String? = null,

    @Json(name = "birthPlace")
    val birthPlace: kotlin.String? = null,

    @Json(name = "pregnancySummary")
    val pregnancySummary: kotlin.String? = null,

    @Json(name = "birthSummary")
    val birthSummary: kotlin.String? = null,

    @Json(name = "subjectiveBirthExperience")
    val subjectiveBirthExperience: PreviousBirthsSectionAllOfBirths.SubjectiveBirthExperience? = null,

    @Json(name = "puerperalSepsis")
    val puerperalSepsis: YesNoEnum? = null,

) : Parcelable {

    /**
     *
     *
     * Values: Good,Normal,Bad
     */
    enum class SubjectiveBirthExperience(val value: kotlin.String) {
        @Json(name = "good")
        Good("good"),

        @Json(name = "normal")
        Normal("normal"),

        @Json(name = "bad")
        Bad("bad"),
    }
}
