/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 * Post or put this to the server to save or create up to one of each observation type related to an ultrasound scan
 *
 * @param activityId the ID of the careplan activity that these observations are pointing to (using a cross reference)
 * @param documentUniqueId the unique uuid of the cda document
 * @param date time of the measurement (shall be able to put back in time) will default to now
 * @param offsetDate time of the conception. This field is needed to calculate gestation age
 * @param weight
 * @param bloodPressure
 * @param urine Each Urin observation as an entry eg. [\"+A\", \"S\", \"Leu]
 * @param edema
 * @param pubismeasurement
 * @param fetuses
 */
@Parcelize
data class SaveRegularObservationsRequest(

    // the ID of the careplan activity that these observations are pointing to (using a cross reference)
    @Json(name = "activityId")
    val activityId: kotlin.String? = null,

    // the unique uuid of the cda document
    @Json(name = "documentUniqueId")
    val documentUniqueId: kotlin.String? = null,

    // time of the measurement (shall be able to put back in time) will default to now
    @Json(name = "date")
    val date: java.time.LocalDateTime? = null,

    // time of the conception. This field is needed to calculate gestation age
    @Json(name = "offsetDate")
    val offsetDate: java.time.LocalDateTime? = null,

    @Json(name = "weight")
    val weight: java.math.BigDecimal? = null,

    @Json(name = "bloodPressure")
    val bloodPressure: SaveRegularObservationsRequestBloodPressure? = null,

    // Each Urin observation as an entry eg. [\"+A\", \"S\", \"Leu]
    @Json(name = "urine")
    val urine: kotlin.collections.List<kotlin.String>? = null,

    @Json(name = "edema")
    val edema: kotlin.String? = null,

    @Json(name = "pubismeasurement")
    val pubismeasurement: java.math.BigDecimal? = null,

    @Json(name = "fetuses")
    val fetuses: kotlin.collections.List<SaveRegularObservationsRequestFetuses>? = null,

) : Parcelable
