/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport",
)

package dk.nsp.models

import android.os.Parcelable
import com.squareup.moshi.Json
import kotlinx.parcelize.Parcelize

/**
 * Post or put this to the server to save or create up to one of each observation type related to an ultrasound scan
 *
 * @param date time of the measurement (shall be able to be put back in time) will default to now
 * @param offsetDate time of the conception. This field is needed to calculate gestation age
 * @param activityId the ID of the careplan activity that these observations are pointing to (using a cross reference)
 * @param documentUniqueId the unique uuid of the cda document
 * @param amnioticFluid
 * @param flow
 * @param cervix
 * @param dvp
 * @param fetuses
 */
@Parcelize
data class SaveUltrasoundObservationsRequest(

    // time of the measurement (shall be able to be put back in time) will default to now
    @Json(name = "date")
    val date: java.time.LocalDateTime? = null,

    // time of the conception. This field is needed to calculate gestation age
    @Json(name = "offsetDate")
    val offsetDate: java.time.LocalDateTime? = null,

    // the ID of the careplan activity that these observations are pointing to (using a cross reference)
    @Json(name = "activityId")
    val activityId: kotlin.String? = null,

    // the unique uuid of the cda document
    @Json(name = "documentUniqueId")
    val documentUniqueId: kotlin.String? = null,

    @Json(name = "amnioticFluid")
    val amnioticFluid: java.math.BigDecimal? = null,

    @Json(name = "flow")
    val flow: SaveUltrasoundObservationsRequest.Flow? = null,

    @Json(name = "cervix")
    val cervix: java.math.BigDecimal? = null,

    @Json(name = "dvp")
    val dvp: java.math.BigDecimal? = null,

    @Json(name = "fetuses")
    val fetuses: kotlin.collections.List<SaveUltrasoundObservationsRequestFetuses>? = null,

) : Parcelable {

    /**
     *
     *
     * Values: Normal,Abnormal,Tobecontinued
     */
    enum class Flow(val value: kotlin.String) {
        @Json(name = "normal")
        Normal("normal"),

        @Json(name = "abnormal")
        Abnormal("abnormal"),

        @Json(name = "tobecontinued")
        Tobecontinued("tobecontinued"),
    }
}
