/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.shared.util

import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.Job
import kotlinx.coroutines.async
import kotlinx.coroutines.launch

typealias CoroutineScopeFunction = suspend CoroutineScope.() -> Unit
typealias CoroutineScopeFunction0<O> = suspend CoroutineScope.() -> O

/**
 * Same as [async] ([Dispatchers.Default])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> T
 * @return [Deferred]<T>
 */
inline fun <T> CoroutineScope.asyncDefault(
    noinline action: CoroutineScopeFunction0<T>,
): Deferred<T> = async(Dispatchers.Default, block = action)

/**
 * same as [launch] ([Dispatchers.Default])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> [Unit]
 * @return [Job]
 */
inline fun CoroutineScope.launchDefault(
    noinline action: CoroutineScopeFunction,
): Job = launch(Dispatchers.Default, block = action)

/**
 * same as [launch] ([Dispatchers.Main])
 * @receiver [CoroutineScope]
 * @param action suspend [CoroutineScope].() -> [Unit]
 * @return [Job]
 */
inline fun CoroutineScope.launchMain(
    noinline action: CoroutineScopeFunction,
): Job = launch(Dispatchers.Main, block = action)
