/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp

import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertFalse
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.assertThrows

class BuildFlavorTest {

    class CompanionTest {
        @Test
        fun from() {
            BuildFlavor.from("projectEnv").assertEquals(BuildFlavor.ProjectEnv)
            BuildFlavor.from("internalTest")
                .assertEquals(BuildFlavor.InternalTest)
            BuildFlavor.from("staging1").assertEquals(BuildFlavor.Staging1)
            BuildFlavor.from("staging2").assertEquals(BuildFlavor.Staging2)
            BuildFlavor.from("mock").assertEquals(BuildFlavor.Mock)
            BuildFlavor.from("googlePlay").assertEquals(BuildFlavor.GooglePlay)

            assertThrows<RuntimeException> {
                BuildFlavor.from("ProjectEnv")
            }

            assertThrows<RuntimeException> {
                BuildFlavor.from("InternalTest")
            }

            assertThrows<RuntimeException> {
                BuildFlavor.from("Staging1")
            }

            assertThrows<RuntimeException> {
                BuildFlavor.from("Staging2")
            }

            assertThrows<RuntimeException> {
                BuildFlavor.from("staging3")
            }

            assertThrows<RuntimeException> {
                BuildFlavor.from("Mock")
            }

            assertThrows<RuntimeException> {
                BuildFlavor.from("GooglePlay")
            }

            assertThrows<RuntimeException> {
                BuildFlavor.from("")
            }
        }
    }

    @Test
    fun isFirebaseEnabled() {
        BuildFlavor.ProjectEnv.isFirebaseEnabled.assertFalse()
        BuildFlavor.InternalTest.isFirebaseEnabled.assertFalse()
        BuildFlavor.Staging1.isFirebaseEnabled.assertFalse()
        BuildFlavor.Staging2.isFirebaseEnabled.assertFalse()
        BuildFlavor.Mock.isFirebaseEnabled.assertFalse()
        BuildFlavor.GooglePlay.isFirebaseEnabled.assertFalse()

        // TODO: Currently no way to properly mock BuildConfig.DEBUG
    }

    @Test
    fun isFirebaseDistributionEnabled() {
        BuildFlavor.ProjectEnv.isFirebaseDistributionEnabled.assertFalse()
        BuildFlavor.InternalTest.isFirebaseDistributionEnabled.assertFalse()
        BuildFlavor.Staging1.isFirebaseDistributionEnabled.assertFalse()
        BuildFlavor.Staging2.isFirebaseDistributionEnabled.assertFalse()
        BuildFlavor.Mock.isFirebaseDistributionEnabled.assertFalse()
        BuildFlavor.GooglePlay.isFirebaseDistributionEnabled.assertFalse()

        // TODO: Currently no way to properly mock BuildConfig.DEBUG
    }
}
