/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.shared.util.extensions

import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertNotContains
import org.junit.jupiter.api.Test

class ListsTest {

    class Replace {
        @Test
        fun emptyList() {
            val emptyReplace = emptyList<Int>().replace(1, 2)
            emptyReplace.size.assertEquals(0)
        }

        @Test
        fun ints() {
            val intList = listOf(1, 2, 3)
                .replace(2, 4)
            intList.size.assertEquals(3)
            intList.getOrNull(1).assertEquals(4)

            val noReplacements = intList.replace(5, 6)
            noReplacements.assertNotContains(5)
            noReplacements.assertNotContains(6)
        }

        @Test
        fun strings() {
            val stringList = listOf("val1", "val2", "val3", "val4")
                .replace("val3", "newVal")

            stringList.size.assertEquals(4)
            stringList.getOrNull(2).assertEquals("newVal")

            val noReplacements = stringList.replace("val0", "newerVal")
            noReplacements.assertNotContains("val0")
            noReplacements.assertNotContains("newerVal")
        }
    }
}
